# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_CONVERT_METADATA = Metadata(
    id="5c246decade01d0e869276d986b6a0431ecb382d.boutiques",
    name="metric-convert",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricConvertToNiftiParameters = typing.TypedDict('MetricConvertToNiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["to_nifti"]],
    "metric_in": InputPathType,
    "nifti_out": str,
})
MetricConvertToNiftiParametersTagged = typing.TypedDict('MetricConvertToNiftiParametersTagged', {
    "@type": typing.Literal["to_nifti"],
    "metric_in": InputPathType,
    "nifti_out": str,
})


MetricConvertFromNiftiParameters = typing.TypedDict('MetricConvertFromNiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["from_nifti"]],
    "nifti_in": InputPathType,
    "surface_in": InputPathType,
    "metric_out": str,
})
MetricConvertFromNiftiParametersTagged = typing.TypedDict('MetricConvertFromNiftiParametersTagged', {
    "@type": typing.Literal["from_nifti"],
    "nifti_in": InputPathType,
    "surface_in": InputPathType,
    "metric_out": str,
})


MetricConvertParameters = typing.TypedDict('MetricConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-convert"]],
    "to_nifti": typing.NotRequired[MetricConvertToNiftiParameters | None],
    "from_nifti": typing.NotRequired[MetricConvertFromNiftiParameters | None],
})
MetricConvertParametersTagged = typing.TypedDict('MetricConvertParametersTagged', {
    "@type": typing.Literal["workbench/metric-convert"],
    "to_nifti": typing.NotRequired[MetricConvertToNiftiParameters | None],
    "from_nifti": typing.NotRequired[MetricConvertFromNiftiParameters | None],
})


class MetricConvertToNiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricConvertToNiftiParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    nifti_out: OutputPathType
    """the output nifti file"""


def metric_convert_to_nifti_params(
    metric_in: InputPathType,
    nifti_out: str,
) -> MetricConvertToNiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        metric_in: the metric to convert.
        nifti_out: the output nifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to_nifti",
        "metric_in": metric_in,
        "nifti_out": nifti_out,
    }
    return params


def metric_convert_to_nifti_cargs(
    params: MetricConvertToNiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-to-nifti")
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(params.get("nifti_out", None))
    return cargs


def metric_convert_to_nifti_outputs(
    params: MetricConvertToNiftiParameters,
    execution: Execution,
) -> MetricConvertToNiftiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricConvertToNiftiOutputs(
        root=execution.output_file("."),
        nifti_out=execution.output_file(params.get("nifti_out", None)),
    )
    return ret


class MetricConvertFromNiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricConvertFromNiftiParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def metric_convert_from_nifti_params(
    nifti_in: InputPathType,
    surface_in: InputPathType,
    metric_out: str,
) -> MetricConvertFromNiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        nifti_in: the nifti file to convert.
        surface_in: surface file to use number of vertices and structure from.
        metric_out: the output metric file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from_nifti",
        "nifti_in": nifti_in,
        "surface_in": surface_in,
        "metric_out": metric_out,
    }
    return params


def metric_convert_from_nifti_cargs(
    params: MetricConvertFromNiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-from-nifti")
    cargs.append(execution.input_file(params.get("nifti_in", None)))
    cargs.append(execution.input_file(params.get("surface_in", None)))
    cargs.append(params.get("metric_out", None))
    return cargs


def metric_convert_from_nifti_outputs(
    params: MetricConvertFromNiftiParameters,
    execution: Execution,
) -> MetricConvertFromNiftiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricConvertFromNiftiOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


class MetricConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricConvertParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    to_nifti: MetricConvertToNiftiOutputs | None
    """Outputs from `metric_convert_to_nifti_outputs`."""
    from_nifti: MetricConvertFromNiftiOutputs | None
    """Outputs from `metric_convert_from_nifti_outputs`."""


def metric_convert_params(
    to_nifti: MetricConvertToNiftiParameters | None = None,
    from_nifti: MetricConvertFromNiftiParameters | None = None,
) -> MetricConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        to_nifti: convert metric to nifti.
        from_nifti: convert nifti to metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-convert",
    }
    if to_nifti is not None:
        params["to_nifti"] = to_nifti
    if from_nifti is not None:
        params["from_nifti"] = from_nifti
    return params


def metric_convert_cargs(
    params: MetricConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-convert")
    if params.get("to_nifti", None) is not None:
        cargs.extend(metric_convert_to_nifti_cargs(params.get("to_nifti", None), execution))
    if params.get("from_nifti", None) is not None:
        cargs.extend(metric_convert_from_nifti_cargs(params.get("from_nifti", None), execution))
    return cargs


def metric_convert_outputs(
    params: MetricConvertParameters,
    execution: Execution,
) -> MetricConvertOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricConvertOutputs(
        root=execution.output_file("."),
        to_nifti=metric_convert_to_nifti_outputs(params.get("to_nifti"), execution) if params.get("to_nifti") else None,
        from_nifti=metric_convert_from_nifti_outputs(params.get("from_nifti"), execution) if params.get("from_nifti") else None,
    )
    return ret


def metric_convert_execute(
    params: MetricConvertParameters,
    runner: Runner | None = None,
) -> MetricConvertOutputs:
    """
    metric-convert
    
    Convert metric file to fake nifti.
    
    The purpose of this command is to convert between metric files and nifti1 so
    that gifti-unaware programs can operate on the data. You must specify
    exactly one of the options.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_CONVERT_METADATA)
    params = execution.params(params)
    cargs = metric_convert_cargs(params, execution)
    ret = metric_convert_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_convert(
    to_nifti: MetricConvertToNiftiParameters | None = None,
    from_nifti: MetricConvertFromNiftiParameters | None = None,
    runner: Runner | None = None,
) -> MetricConvertOutputs:
    """
    metric-convert
    
    Convert metric file to fake nifti.
    
    The purpose of this command is to convert between metric files and nifti1 so
    that gifti-unaware programs can operate on the data. You must specify
    exactly one of the options.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        to_nifti: convert metric to nifti.
        from_nifti: convert nifti to metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricConvertOutputs`).
    """
    params = metric_convert_params(
        to_nifti=to_nifti,
        from_nifti=from_nifti,
    )
    return metric_convert_execute(params, runner)


__all__ = [
    "METRIC_CONVERT_METADATA",
    "MetricConvertFromNiftiOutputs",
    "MetricConvertOutputs",
    "MetricConvertToNiftiOutputs",
    "metric_convert",
    "metric_convert_execute",
    "metric_convert_from_nifti_params",
    "metric_convert_params",
    "metric_convert_to_nifti_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_CAPTURE_PLANE_METADATA = Metadata(
    id="fce982f3ac61b3a6dc85a30dbe38533edd029421.boutiques",
    name="volume-capture-plane",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeCapturePlaneParameters = typing.TypedDict('VolumeCapturePlaneParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-capture-plane"]],
    "volume": InputPathType,
    "subvolume": str,
    "interp": str,
    "h_dim": int,
    "v_dim": int,
    "scale_min": float,
    "scale_max": float,
    "bottom_left_x": float,
    "bottom_left_y": float,
    "bottom_left_z": float,
    "bottom_right_x": float,
    "bottom_right_y": float,
    "bottom_right_z": float,
    "top_left_x": float,
    "top_left_y": float,
    "top_left_z": float,
    "image": str,
})
VolumeCapturePlaneParametersTagged = typing.TypedDict('VolumeCapturePlaneParametersTagged', {
    "@type": typing.Literal["workbench/volume-capture-plane"],
    "volume": InputPathType,
    "subvolume": str,
    "interp": str,
    "h_dim": int,
    "v_dim": int,
    "scale_min": float,
    "scale_max": float,
    "bottom_left_x": float,
    "bottom_left_y": float,
    "bottom_left_z": float,
    "bottom_right_x": float,
    "bottom_right_y": float,
    "bottom_right_z": float,
    "top_left_x": float,
    "top_left_y": float,
    "top_left_z": float,
    "image": str,
})


class VolumeCapturePlaneOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeCapturePlaneParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_capture_plane_params(
    volume: InputPathType,
    subvolume: str,
    interp: str,
    h_dim: int,
    v_dim: int,
    scale_min: float,
    scale_max: float,
    bottom_left_x: float,
    bottom_left_y: float,
    bottom_left_z: float,
    bottom_right_x: float,
    bottom_right_y: float,
    bottom_right_z: float,
    top_left_x: float,
    top_left_y: float,
    top_left_z: float,
    image: str,
) -> VolumeCapturePlaneParametersTagged:
    """
    Build parameters.
    
    Args:
        volume: the volume file to interpolate from.
        subvolume: the name or number of the subvolume to use.
        interp: interpolation type.
        h_dim: width of output image, in pixels.
        v_dim: height of output image, in pixels.
        scale_min: value to render as black.
        scale_max: value to render as white.
        bottom_left_x: x-coordinate of the bottom left of the output image.
        bottom_left_y: y-coordinate of the bottom left of the output image.
        bottom_left_z: z-coordinate of the bottom left of the output image.
        bottom_right_x: x-coordinate of the bottom right of the output image.
        bottom_right_y: y-coordinate of the bottom right of the output image.
        bottom_right_z: z-coordinate of the bottom right of the output image.
        top_left_x: x-coordinate of the top left of the output image.
        top_left_y: y-coordinate of the top left of the output image.
        top_left_z: z-coordinate of the top left of the output image.
        image: output - the output image.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-capture-plane",
        "volume": volume,
        "subvolume": subvolume,
        "interp": interp,
        "h_dim": h_dim,
        "v_dim": v_dim,
        "scale_min": scale_min,
        "scale_max": scale_max,
        "bottom_left_x": bottom_left_x,
        "bottom_left_y": bottom_left_y,
        "bottom_left_z": bottom_left_z,
        "bottom_right_x": bottom_right_x,
        "bottom_right_y": bottom_right_y,
        "bottom_right_z": bottom_right_z,
        "top_left_x": top_left_x,
        "top_left_y": top_left_y,
        "top_left_z": top_left_z,
        "image": image,
    }
    return params


def volume_capture_plane_cargs(
    params: VolumeCapturePlaneParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-capture-plane")
    cargs.append(execution.input_file(params.get("volume", None)))
    cargs.append(params.get("subvolume", None))
    cargs.append(params.get("interp", None))
    cargs.append(str(params.get("h_dim", None)))
    cargs.append(str(params.get("v_dim", None)))
    cargs.append(str(params.get("scale_min", None)))
    cargs.append(str(params.get("scale_max", None)))
    cargs.append(str(params.get("bottom_left_x", None)))
    cargs.append(str(params.get("bottom_left_y", None)))
    cargs.append(str(params.get("bottom_left_z", None)))
    cargs.append(str(params.get("bottom_right_x", None)))
    cargs.append(str(params.get("bottom_right_y", None)))
    cargs.append(str(params.get("bottom_right_z", None)))
    cargs.append(str(params.get("top_left_x", None)))
    cargs.append(str(params.get("top_left_y", None)))
    cargs.append(str(params.get("top_left_z", None)))
    cargs.append(params.get("image", None))
    return cargs


def volume_capture_plane_outputs(
    params: VolumeCapturePlaneParameters,
    execution: Execution,
) -> VolumeCapturePlaneOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeCapturePlaneOutputs(
        root=execution.output_file("."),
    )
    return ret


def volume_capture_plane_execute(
    params: VolumeCapturePlaneParameters,
    runner: Runner | None = None,
) -> VolumeCapturePlaneOutputs:
    """
    volume-capture-plane
    
    Interpolate image from plane through volume.
    
    NOTE: If you want to generate an image with all of the capabilities of the
    GUI rendering, see -show-scene.
    
    Renders an image of an arbitrary plane through the volume file, with a
    simple linear grayscale palette. The parameter <interp> must be one of:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCapturePlaneOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_CAPTURE_PLANE_METADATA)
    params = execution.params(params)
    cargs = volume_capture_plane_cargs(params, execution)
    ret = volume_capture_plane_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_capture_plane(
    volume: InputPathType,
    subvolume: str,
    interp: str,
    h_dim: int,
    v_dim: int,
    scale_min: float,
    scale_max: float,
    bottom_left_x: float,
    bottom_left_y: float,
    bottom_left_z: float,
    bottom_right_x: float,
    bottom_right_y: float,
    bottom_right_z: float,
    top_left_x: float,
    top_left_y: float,
    top_left_z: float,
    image: str,
    runner: Runner | None = None,
) -> VolumeCapturePlaneOutputs:
    """
    volume-capture-plane
    
    Interpolate image from plane through volume.
    
    NOTE: If you want to generate an image with all of the capabilities of the
    GUI rendering, see -show-scene.
    
    Renders an image of an arbitrary plane through the volume file, with a
    simple linear grayscale palette. The parameter <interp> must be one of:
    
    CUBIC
    ENCLOSING_VOXEL
    TRILINEAR.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume: the volume file to interpolate from.
        subvolume: the name or number of the subvolume to use.
        interp: interpolation type.
        h_dim: width of output image, in pixels.
        v_dim: height of output image, in pixels.
        scale_min: value to render as black.
        scale_max: value to render as white.
        bottom_left_x: x-coordinate of the bottom left of the output image.
        bottom_left_y: y-coordinate of the bottom left of the output image.
        bottom_left_z: z-coordinate of the bottom left of the output image.
        bottom_right_x: x-coordinate of the bottom right of the output image.
        bottom_right_y: y-coordinate of the bottom right of the output image.
        bottom_right_z: z-coordinate of the bottom right of the output image.
        top_left_x: x-coordinate of the top left of the output image.
        top_left_y: y-coordinate of the top left of the output image.
        top_left_z: z-coordinate of the top left of the output image.
        image: output - the output image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeCapturePlaneOutputs`).
    """
    params = volume_capture_plane_params(
        volume=volume,
        subvolume=subvolume,
        interp=interp,
        h_dim=h_dim,
        v_dim=v_dim,
        scale_min=scale_min,
        scale_max=scale_max,
        bottom_left_x=bottom_left_x,
        bottom_left_y=bottom_left_y,
        bottom_left_z=bottom_left_z,
        bottom_right_x=bottom_right_x,
        bottom_right_y=bottom_right_y,
        bottom_right_z=bottom_right_z,
        top_left_x=top_left_x,
        top_left_y=top_left_y,
        top_left_z=top_left_z,
        image=image,
    )
    return volume_capture_plane_execute(params, runner)


__all__ = [
    "VOLUME_CAPTURE_PLANE_METADATA",
    "VolumeCapturePlaneOutputs",
    "volume_capture_plane",
    "volume_capture_plane_execute",
    "volume_capture_plane_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_CONVERT_METADATA = Metadata(
    id="70a8b5ced62c481e40ec12dcf2abf0cb66adfb18.boutiques",
    name="cifti-convert",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiConvertToGiftiExtParameters = typing.TypedDict('CiftiConvertToGiftiExtParameters', {
    "@type": typing.NotRequired[typing.Literal["to_gifti_ext"]],
    "cifti_in": InputPathType,
    "gifti_out": str,
})
CiftiConvertToGiftiExtParametersTagged = typing.TypedDict('CiftiConvertToGiftiExtParametersTagged', {
    "@type": typing.Literal["to_gifti_ext"],
    "cifti_in": InputPathType,
    "gifti_out": str,
})


CiftiConvertResetTimepointsParameters = typing.TypedDict('CiftiConvertResetTimepointsParameters', {
    "@type": typing.NotRequired[typing.Literal["reset_timepoints"]],
    "timestep": float,
    "timestart": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})
CiftiConvertResetTimepointsParametersTagged = typing.TypedDict('CiftiConvertResetTimepointsParametersTagged', {
    "@type": typing.Literal["reset_timepoints"],
    "timestep": float,
    "timestart": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})


CiftiConvertReplaceBinaryParameters = typing.TypedDict('CiftiConvertReplaceBinaryParameters', {
    "@type": typing.NotRequired[typing.Literal["replace_binary"]],
    "binary_in": str,
    "opt_flip_endian": bool,
    "opt_transpose": bool,
})
CiftiConvertReplaceBinaryParametersTagged = typing.TypedDict('CiftiConvertReplaceBinaryParametersTagged', {
    "@type": typing.Literal["replace_binary"],
    "binary_in": str,
    "opt_flip_endian": bool,
    "opt_transpose": bool,
})


CiftiConvertFromGiftiExtParameters = typing.TypedDict('CiftiConvertFromGiftiExtParameters', {
    "@type": typing.NotRequired[typing.Literal["from_gifti_ext"]],
    "gifti_in": str,
    "cifti_out": str,
    "reset_timepoints": typing.NotRequired[CiftiConvertResetTimepointsParameters | None],
    "opt_reset_scalars": bool,
    "opt_column_reset_scalars": bool,
    "replace_binary": typing.NotRequired[CiftiConvertReplaceBinaryParameters | None],
})
CiftiConvertFromGiftiExtParametersTagged = typing.TypedDict('CiftiConvertFromGiftiExtParametersTagged', {
    "@type": typing.Literal["from_gifti_ext"],
    "gifti_in": str,
    "cifti_out": str,
    "reset_timepoints": typing.NotRequired[CiftiConvertResetTimepointsParameters | None],
    "opt_reset_scalars": bool,
    "opt_column_reset_scalars": bool,
    "replace_binary": typing.NotRequired[CiftiConvertReplaceBinaryParameters | None],
})


CiftiConvertToNiftiParameters = typing.TypedDict('CiftiConvertToNiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["to_nifti"]],
    "cifti_in": InputPathType,
    "nifti_out": str,
    "opt_smaller_file": bool,
    "opt_smaller_dims": bool,
})
CiftiConvertToNiftiParametersTagged = typing.TypedDict('CiftiConvertToNiftiParametersTagged', {
    "@type": typing.Literal["to_nifti"],
    "cifti_in": InputPathType,
    "nifti_out": str,
    "opt_smaller_file": bool,
    "opt_smaller_dims": bool,
})


CiftiConvertResetTimepoints1Parameters = typing.TypedDict('CiftiConvertResetTimepoints1Parameters', {
    "@type": typing.NotRequired[typing.Literal["reset_timepoints_1"]],
    "timestep": float,
    "timestart": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})
CiftiConvertResetTimepoints1ParametersTagged = typing.TypedDict('CiftiConvertResetTimepoints1ParametersTagged', {
    "@type": typing.Literal["reset_timepoints_1"],
    "timestep": float,
    "timestart": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})


CiftiConvertFromNiftiParameters = typing.TypedDict('CiftiConvertFromNiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["from_nifti"]],
    "nifti_in": InputPathType,
    "cifti_template": InputPathType,
    "cifti_out": str,
    "reset_timepoints": typing.NotRequired[CiftiConvertResetTimepoints1Parameters | None],
    "opt_reset_scalars": bool,
})
CiftiConvertFromNiftiParametersTagged = typing.TypedDict('CiftiConvertFromNiftiParametersTagged', {
    "@type": typing.Literal["from_nifti"],
    "nifti_in": InputPathType,
    "cifti_template": InputPathType,
    "cifti_out": str,
    "reset_timepoints": typing.NotRequired[CiftiConvertResetTimepoints1Parameters | None],
    "opt_reset_scalars": bool,
})


CiftiConvertToTextParameters = typing.TypedDict('CiftiConvertToTextParameters', {
    "@type": typing.NotRequired[typing.Literal["to_text"]],
    "cifti_in": InputPathType,
    "text_out": str,
    "opt_col_delim_delim_string": typing.NotRequired[str | None],
})
CiftiConvertToTextParametersTagged = typing.TypedDict('CiftiConvertToTextParametersTagged', {
    "@type": typing.Literal["to_text"],
    "cifti_in": InputPathType,
    "text_out": str,
    "opt_col_delim_delim_string": typing.NotRequired[str | None],
})


CiftiConvertResetTimepoints2Parameters = typing.TypedDict('CiftiConvertResetTimepoints2Parameters', {
    "@type": typing.NotRequired[typing.Literal["reset_timepoints_2"]],
    "timestep": float,
    "timestart": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})
CiftiConvertResetTimepoints2ParametersTagged = typing.TypedDict('CiftiConvertResetTimepoints2ParametersTagged', {
    "@type": typing.Literal["reset_timepoints_2"],
    "timestep": float,
    "timestart": float,
    "opt_unit_unit": typing.NotRequired[str | None],
})


CiftiConvertFromTextParameters = typing.TypedDict('CiftiConvertFromTextParameters', {
    "@type": typing.NotRequired[typing.Literal["from_text"]],
    "text_in": str,
    "cifti_template": InputPathType,
    "cifti_out": str,
    "opt_col_delim_delim_string": typing.NotRequired[str | None],
    "reset_timepoints": typing.NotRequired[CiftiConvertResetTimepoints2Parameters | None],
    "opt_reset_scalars": bool,
})
CiftiConvertFromTextParametersTagged = typing.TypedDict('CiftiConvertFromTextParametersTagged', {
    "@type": typing.Literal["from_text"],
    "text_in": str,
    "cifti_template": InputPathType,
    "cifti_out": str,
    "opt_col_delim_delim_string": typing.NotRequired[str | None],
    "reset_timepoints": typing.NotRequired[CiftiConvertResetTimepoints2Parameters | None],
    "opt_reset_scalars": bool,
})


CiftiConvertParameters = typing.TypedDict('CiftiConvertParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-convert"]],
    "to_gifti_ext": typing.NotRequired[CiftiConvertToGiftiExtParameters | None],
    "from_gifti_ext": typing.NotRequired[CiftiConvertFromGiftiExtParameters | None],
    "to_nifti": typing.NotRequired[CiftiConvertToNiftiParameters | None],
    "from_nifti": typing.NotRequired[CiftiConvertFromNiftiParameters | None],
    "to_text": typing.NotRequired[CiftiConvertToTextParameters | None],
    "from_text": typing.NotRequired[CiftiConvertFromTextParameters | None],
})
CiftiConvertParametersTagged = typing.TypedDict('CiftiConvertParametersTagged', {
    "@type": typing.Literal["workbench/cifti-convert"],
    "to_gifti_ext": typing.NotRequired[CiftiConvertToGiftiExtParameters | None],
    "from_gifti_ext": typing.NotRequired[CiftiConvertFromGiftiExtParameters | None],
    "to_nifti": typing.NotRequired[CiftiConvertToNiftiParameters | None],
    "from_nifti": typing.NotRequired[CiftiConvertFromNiftiParameters | None],
    "to_text": typing.NotRequired[CiftiConvertToTextParameters | None],
    "from_text": typing.NotRequired[CiftiConvertFromTextParameters | None],
})


def cifti_convert_to_gifti_ext_params(
    cifti_in: InputPathType,
    gifti_out: str,
) -> CiftiConvertToGiftiExtParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti file.
        gifti_out: output - the output gifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to_gifti_ext",
        "cifti_in": cifti_in,
        "gifti_out": gifti_out,
    }
    return params


def cifti_convert_to_gifti_ext_cargs(
    params: CiftiConvertToGiftiExtParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-to-gifti-ext")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("gifti_out", None))
    return cargs


def cifti_convert_reset_timepoints_params(
    timestep: float,
    timestart: float,
    opt_unit_unit: str | None = None,
) -> CiftiConvertResetTimepointsParametersTagged:
    """
    Build parameters.
    
    Args:
        timestep: the desired time between frames.
        timestart: the desired time offset of the initial frame.
        opt_unit_unit: use a unit other than time: unit identifier (default\
            SECOND).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "reset_timepoints",
        "timestep": timestep,
        "timestart": timestart,
    }
    if opt_unit_unit is not None:
        params["opt_unit_unit"] = opt_unit_unit
    return params


def cifti_convert_reset_timepoints_cargs(
    params: CiftiConvertResetTimepointsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-reset-timepoints")
    cargs.append(str(params.get("timestep", None)))
    cargs.append(str(params.get("timestart", None)))
    if params.get("opt_unit_unit", None) is not None:
        cargs.extend([
            "-unit",
            params.get("opt_unit_unit", None)
        ])
    return cargs


def cifti_convert_replace_binary_params(
    binary_in: str,
    opt_flip_endian: bool = False,
    opt_transpose: bool = False,
) -> CiftiConvertReplaceBinaryParametersTagged:
    """
    Build parameters.
    
    Args:
        binary_in: the binary file that contains replacement data.
        opt_flip_endian: byteswap the binary file.
        opt_transpose: transpose the binary file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "replace_binary",
        "binary_in": binary_in,
        "opt_flip_endian": opt_flip_endian,
        "opt_transpose": opt_transpose,
    }
    return params


def cifti_convert_replace_binary_cargs(
    params: CiftiConvertReplaceBinaryParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-replace-binary")
    cargs.append(params.get("binary_in", None))
    if params.get("opt_flip_endian", False):
        cargs.append("-flip-endian")
    if params.get("opt_transpose", False):
        cargs.append("-transpose")
    return cargs


class CiftiConvertFromGiftiExtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiConvertFromGiftiExtParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_convert_from_gifti_ext_params(
    gifti_in: str,
    cifti_out: str,
    reset_timepoints: CiftiConvertResetTimepointsParameters | None = None,
    opt_reset_scalars: bool = False,
    opt_column_reset_scalars: bool = False,
    replace_binary: CiftiConvertReplaceBinaryParameters | None = None,
) -> CiftiConvertFromGiftiExtParametersTagged:
    """
    Build parameters.
    
    Args:
        gifti_in: the input gifti file.
        cifti_out: the output cifti file.
        reset_timepoints: reset the mapping along rows to timepoints, taking\
            length from the gifti file.
        opt_reset_scalars: reset mapping along rows to scalars, taking length\
            from the gifti file.
        opt_column_reset_scalars: reset mapping along columns to scalar (useful\
            for changing number of series in a sdseries file).
        replace_binary: replace data with a binary file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from_gifti_ext",
        "gifti_in": gifti_in,
        "cifti_out": cifti_out,
        "opt_reset_scalars": opt_reset_scalars,
        "opt_column_reset_scalars": opt_column_reset_scalars,
    }
    if reset_timepoints is not None:
        params["reset_timepoints"] = reset_timepoints
    if replace_binary is not None:
        params["replace_binary"] = replace_binary
    return params


def cifti_convert_from_gifti_ext_cargs(
    params: CiftiConvertFromGiftiExtParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-from-gifti-ext")
    cargs.append(params.get("gifti_in", None))
    cargs.append(params.get("cifti_out", None))
    if params.get("reset_timepoints", None) is not None:
        cargs.extend(cifti_convert_reset_timepoints_cargs(params.get("reset_timepoints", None), execution))
    if params.get("opt_reset_scalars", False):
        cargs.append("-reset-scalars")
    if params.get("opt_column_reset_scalars", False):
        cargs.append("-column-reset-scalars")
    if params.get("replace_binary", None) is not None:
        cargs.extend(cifti_convert_replace_binary_cargs(params.get("replace_binary", None), execution))
    return cargs


def cifti_convert_from_gifti_ext_outputs(
    params: CiftiConvertFromGiftiExtParameters,
    execution: Execution,
) -> CiftiConvertFromGiftiExtOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiConvertFromGiftiExtOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


class CiftiConvertToNiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiConvertToNiftiParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    nifti_out: OutputPathType
    """the output nifti file"""


def cifti_convert_to_nifti_params(
    cifti_in: InputPathType,
    nifti_out: str,
    opt_smaller_file: bool = False,
    opt_smaller_dims: bool = False,
) -> CiftiConvertToNiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti file.
        nifti_out: the output nifti file.
        opt_smaller_file: use better-fitting dimension lengths.
        opt_smaller_dims: minimize the largest dimension, for tools that don't\
            like large indices.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to_nifti",
        "cifti_in": cifti_in,
        "nifti_out": nifti_out,
        "opt_smaller_file": opt_smaller_file,
        "opt_smaller_dims": opt_smaller_dims,
    }
    return params


def cifti_convert_to_nifti_cargs(
    params: CiftiConvertToNiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-to-nifti")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("nifti_out", None))
    if params.get("opt_smaller_file", False):
        cargs.append("-smaller-file")
    if params.get("opt_smaller_dims", False):
        cargs.append("-smaller-dims")
    return cargs


def cifti_convert_to_nifti_outputs(
    params: CiftiConvertToNiftiParameters,
    execution: Execution,
) -> CiftiConvertToNiftiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiConvertToNiftiOutputs(
        root=execution.output_file("."),
        nifti_out=execution.output_file(params.get("nifti_out", None)),
    )
    return ret


def cifti_convert_reset_timepoints_1_params(
    timestep: float,
    timestart: float,
    opt_unit_unit: str | None = None,
) -> CiftiConvertResetTimepoints1ParametersTagged:
    """
    Build parameters.
    
    Args:
        timestep: the desired time between frames.
        timestart: the desired time offset of the initial frame.
        opt_unit_unit: use a unit other than time: unit identifier (default\
            SECOND).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "reset_timepoints_1",
        "timestep": timestep,
        "timestart": timestart,
    }
    if opt_unit_unit is not None:
        params["opt_unit_unit"] = opt_unit_unit
    return params


def cifti_convert_reset_timepoints_1_cargs(
    params: CiftiConvertResetTimepoints1Parameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-reset-timepoints")
    cargs.append(str(params.get("timestep", None)))
    cargs.append(str(params.get("timestart", None)))
    if params.get("opt_unit_unit", None) is not None:
        cargs.extend([
            "-unit",
            params.get("opt_unit_unit", None)
        ])
    return cargs


class CiftiConvertFromNiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiConvertFromNiftiParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_convert_from_nifti_params(
    nifti_in: InputPathType,
    cifti_template: InputPathType,
    cifti_out: str,
    reset_timepoints: CiftiConvertResetTimepoints1Parameters | None = None,
    opt_reset_scalars: bool = False,
) -> CiftiConvertFromNiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        nifti_in: the input nifti file.
        cifti_template: a cifti file with the dimension(s) and mapping(s) that\
            should be used.
        cifti_out: the output cifti file.
        reset_timepoints: reset the mapping along rows to timepoints, taking\
            length from the nifti file.
        opt_reset_scalars: reset mapping along rows to scalars, taking length\
            from the nifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from_nifti",
        "nifti_in": nifti_in,
        "cifti_template": cifti_template,
        "cifti_out": cifti_out,
        "opt_reset_scalars": opt_reset_scalars,
    }
    if reset_timepoints is not None:
        params["reset_timepoints"] = reset_timepoints
    return params


def cifti_convert_from_nifti_cargs(
    params: CiftiConvertFromNiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-from-nifti")
    cargs.append(execution.input_file(params.get("nifti_in", None)))
    cargs.append(execution.input_file(params.get("cifti_template", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("reset_timepoints", None) is not None:
        cargs.extend(cifti_convert_reset_timepoints_1_cargs(params.get("reset_timepoints", None), execution))
    if params.get("opt_reset_scalars", False):
        cargs.append("-reset-scalars")
    return cargs


def cifti_convert_from_nifti_outputs(
    params: CiftiConvertFromNiftiParameters,
    execution: Execution,
) -> CiftiConvertFromNiftiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiConvertFromNiftiOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_convert_to_text_params(
    cifti_in: InputPathType,
    text_out: str,
    opt_col_delim_delim_string: str | None = None,
) -> CiftiConvertToTextParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti file.
        text_out: output - the output text file.
        opt_col_delim_delim_string: choose string to put between elements in a\
            row: the string to use (default is a tab character).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "to_text",
        "cifti_in": cifti_in,
        "text_out": text_out,
    }
    if opt_col_delim_delim_string is not None:
        params["opt_col_delim_delim_string"] = opt_col_delim_delim_string
    return params


def cifti_convert_to_text_cargs(
    params: CiftiConvertToTextParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-to-text")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("text_out", None))
    if params.get("opt_col_delim_delim_string", None) is not None:
        cargs.extend([
            "-col-delim",
            params.get("opt_col_delim_delim_string", None)
        ])
    return cargs


def cifti_convert_reset_timepoints_2_params(
    timestep: float,
    timestart: float,
    opt_unit_unit: str | None = None,
) -> CiftiConvertResetTimepoints2ParametersTagged:
    """
    Build parameters.
    
    Args:
        timestep: the desired time between frames.
        timestart: the desired time offset of the initial frame.
        opt_unit_unit: use a unit other than time: unit identifier (default\
            SECOND).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "reset_timepoints_2",
        "timestep": timestep,
        "timestart": timestart,
    }
    if opt_unit_unit is not None:
        params["opt_unit_unit"] = opt_unit_unit
    return params


def cifti_convert_reset_timepoints_2_cargs(
    params: CiftiConvertResetTimepoints2Parameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-reset-timepoints")
    cargs.append(str(params.get("timestep", None)))
    cargs.append(str(params.get("timestart", None)))
    if params.get("opt_unit_unit", None) is not None:
        cargs.extend([
            "-unit",
            params.get("opt_unit_unit", None)
        ])
    return cargs


class CiftiConvertFromTextOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiConvertFromTextParameters | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_convert_from_text_params(
    text_in: str,
    cifti_template: InputPathType,
    cifti_out: str,
    opt_col_delim_delim_string: str | None = None,
    reset_timepoints: CiftiConvertResetTimepoints2Parameters | None = None,
    opt_reset_scalars: bool = False,
) -> CiftiConvertFromTextParametersTagged:
    """
    Build parameters.
    
    Args:
        text_in: the input text file.
        cifti_template: a cifti file with the dimension(s) and mapping(s) that\
            should be used.
        cifti_out: the output cifti file.
        opt_col_delim_delim_string: specify string that is between elements in\
            a row: the string to use (default is any whitespace).
        reset_timepoints: reset the mapping along rows to timepoints, taking\
            length from the text file.
        opt_reset_scalars: reset mapping along rows to scalars, taking length\
            from the text file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "from_text",
        "text_in": text_in,
        "cifti_template": cifti_template,
        "cifti_out": cifti_out,
        "opt_reset_scalars": opt_reset_scalars,
    }
    if opt_col_delim_delim_string is not None:
        params["opt_col_delim_delim_string"] = opt_col_delim_delim_string
    if reset_timepoints is not None:
        params["reset_timepoints"] = reset_timepoints
    return params


def cifti_convert_from_text_cargs(
    params: CiftiConvertFromTextParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-from-text")
    cargs.append(params.get("text_in", None))
    cargs.append(execution.input_file(params.get("cifti_template", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_col_delim_delim_string", None) is not None:
        cargs.extend([
            "-col-delim",
            params.get("opt_col_delim_delim_string", None)
        ])
    if params.get("reset_timepoints", None) is not None:
        cargs.extend(cifti_convert_reset_timepoints_2_cargs(params.get("reset_timepoints", None), execution))
    if params.get("opt_reset_scalars", False):
        cargs.append("-reset-scalars")
    return cargs


def cifti_convert_from_text_outputs(
    params: CiftiConvertFromTextParameters,
    execution: Execution,
) -> CiftiConvertFromTextOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiConvertFromTextOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


class CiftiConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiConvertParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    from_gifti_ext: CiftiConvertFromGiftiExtOutputs | None
    """Outputs from `cifti_convert_from_gifti_ext_outputs`."""
    to_nifti: CiftiConvertToNiftiOutputs | None
    """Outputs from `cifti_convert_to_nifti_outputs`."""
    from_nifti: CiftiConvertFromNiftiOutputs | None
    """Outputs from `cifti_convert_from_nifti_outputs`."""
    from_text: CiftiConvertFromTextOutputs | None
    """Outputs from `cifti_convert_from_text_outputs`."""


def cifti_convert_params(
    to_gifti_ext: CiftiConvertToGiftiExtParameters | None = None,
    from_gifti_ext: CiftiConvertFromGiftiExtParameters | None = None,
    to_nifti: CiftiConvertToNiftiParameters | None = None,
    from_nifti: CiftiConvertFromNiftiParameters | None = None,
    to_text: CiftiConvertToTextParameters | None = None,
    from_text: CiftiConvertFromTextParameters | None = None,
) -> CiftiConvertParametersTagged:
    """
    Build parameters.
    
    Args:
        to_gifti_ext: convert to GIFTI external binary.
        from_gifti_ext: convert a GIFTI made with this command back into a\
            CIFTI.
        to_nifti: convert to NIFTI1.
        from_nifti: convert a NIFTI (1 or 2) file made with this command back\
            into CIFTI.
        to_text: convert to a plain text file.
        from_text: convert from plain text to cifti.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-convert",
    }
    if to_gifti_ext is not None:
        params["to_gifti_ext"] = to_gifti_ext
    if from_gifti_ext is not None:
        params["from_gifti_ext"] = from_gifti_ext
    if to_nifti is not None:
        params["to_nifti"] = to_nifti
    if from_nifti is not None:
        params["from_nifti"] = from_nifti
    if to_text is not None:
        params["to_text"] = to_text
    if from_text is not None:
        params["from_text"] = from_text
    return params


def cifti_convert_cargs(
    params: CiftiConvertParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-convert")
    if params.get("to_gifti_ext", None) is not None:
        cargs.extend(cifti_convert_to_gifti_ext_cargs(params.get("to_gifti_ext", None), execution))
    if params.get("from_gifti_ext", None) is not None:
        cargs.extend(cifti_convert_from_gifti_ext_cargs(params.get("from_gifti_ext", None), execution))
    if params.get("to_nifti", None) is not None:
        cargs.extend(cifti_convert_to_nifti_cargs(params.get("to_nifti", None), execution))
    if params.get("from_nifti", None) is not None:
        cargs.extend(cifti_convert_from_nifti_cargs(params.get("from_nifti", None), execution))
    if params.get("to_text", None) is not None:
        cargs.extend(cifti_convert_to_text_cargs(params.get("to_text", None), execution))
    if params.get("from_text", None) is not None:
        cargs.extend(cifti_convert_from_text_cargs(params.get("from_text", None), execution))
    return cargs


def cifti_convert_outputs(
    params: CiftiConvertParameters,
    execution: Execution,
) -> CiftiConvertOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiConvertOutputs(
        root=execution.output_file("."),
        from_gifti_ext=cifti_convert_from_gifti_ext_outputs(params.get("from_gifti_ext"), execution) if params.get("from_gifti_ext") else None,
        to_nifti=cifti_convert_to_nifti_outputs(params.get("to_nifti"), execution) if params.get("to_nifti") else None,
        from_nifti=cifti_convert_from_nifti_outputs(params.get("from_nifti"), execution) if params.get("from_nifti") else None,
        from_text=cifti_convert_from_text_outputs(params.get("from_text"), execution) if params.get("from_text") else None,
    )
    return ret


def cifti_convert_execute(
    params: CiftiConvertParameters,
    runner: Runner | None = None,
) -> CiftiConvertOutputs:
    """
    cifti-convert
    
    Dump cifti matrix into other formats.
    
    This command is used to convert a full CIFTI matrix to/from formats that can
    be used by programs that don't understand CIFTI. You must specify exactly
    one of -to-gifti-ext, -from-gifti-ext, -to-nifti, -from-nifti, -to-text, or
    -from-text.
    
    If you want to write an existing CIFTI file with a different CIFTI version,
    see -file-convert, and its -cifti-version-convert option.
    
    If you want part of the CIFTI file as a metric, label, or volume file, see
    -cifti-separate. If you want to create a CIFTI file from metric and/or
    volume files, see the -cifti-create-* commands.
    
    If you want to import a matrix that is restricted to an ROI, first create a
    template CIFTI file matching that ROI using a -cifti-create-* command. After
    importing to CIFTI, you can then expand the file into a standard
    brainordinates space with -cifti-create-dense-from-template. If you want to
    export only part of a CIFTI file, first create an roi-restricted CIFTI file
    with -cifti-restrict-dense-mapping.
    
    The -transpose option to -from-gifti-ext is needed if the replacement binary
    file is in column-major order.
    
    The -unit options accept these values:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CONVERT_METADATA)
    params = execution.params(params)
    cargs = cifti_convert_cargs(params, execution)
    ret = cifti_convert_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_convert(
    to_gifti_ext: CiftiConvertToGiftiExtParameters | None = None,
    from_gifti_ext: CiftiConvertFromGiftiExtParameters | None = None,
    to_nifti: CiftiConvertToNiftiParameters | None = None,
    from_nifti: CiftiConvertFromNiftiParameters | None = None,
    to_text: CiftiConvertToTextParameters | None = None,
    from_text: CiftiConvertFromTextParameters | None = None,
    runner: Runner | None = None,
) -> CiftiConvertOutputs:
    """
    cifti-convert
    
    Dump cifti matrix into other formats.
    
    This command is used to convert a full CIFTI matrix to/from formats that can
    be used by programs that don't understand CIFTI. You must specify exactly
    one of -to-gifti-ext, -from-gifti-ext, -to-nifti, -from-nifti, -to-text, or
    -from-text.
    
    If you want to write an existing CIFTI file with a different CIFTI version,
    see -file-convert, and its -cifti-version-convert option.
    
    If you want part of the CIFTI file as a metric, label, or volume file, see
    -cifti-separate. If you want to create a CIFTI file from metric and/or
    volume files, see the -cifti-create-* commands.
    
    If you want to import a matrix that is restricted to an ROI, first create a
    template CIFTI file matching that ROI using a -cifti-create-* command. After
    importing to CIFTI, you can then expand the file into a standard
    brainordinates space with -cifti-create-dense-from-template. If you want to
    export only part of a CIFTI file, first create an roi-restricted CIFTI file
    with -cifti-restrict-dense-mapping.
    
    The -transpose option to -from-gifti-ext is needed if the replacement binary
    file is in column-major order.
    
    The -unit options accept these values:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        to_gifti_ext: convert to GIFTI external binary.
        from_gifti_ext: convert a GIFTI made with this command back into a\
            CIFTI.
        to_nifti: convert to NIFTI1.
        from_nifti: convert a NIFTI (1 or 2) file made with this command back\
            into CIFTI.
        to_text: convert to a plain text file.
        from_text: convert from plain text to cifti.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiConvertOutputs`).
    """
    params = cifti_convert_params(
        to_gifti_ext=to_gifti_ext,
        from_gifti_ext=from_gifti_ext,
        to_nifti=to_nifti,
        from_nifti=from_nifti,
        to_text=to_text,
        from_text=from_text,
    )
    return cifti_convert_execute(params, runner)


__all__ = [
    "CIFTI_CONVERT_METADATA",
    "CiftiConvertFromGiftiExtOutputs",
    "CiftiConvertFromNiftiOutputs",
    "CiftiConvertFromTextOutputs",
    "CiftiConvertOutputs",
    "CiftiConvertToNiftiOutputs",
    "cifti_convert",
    "cifti_convert_execute",
    "cifti_convert_from_gifti_ext_params",
    "cifti_convert_from_nifti_params",
    "cifti_convert_from_text_params",
    "cifti_convert_params",
    "cifti_convert_replace_binary_params",
    "cifti_convert_reset_timepoints_1_params",
    "cifti_convert_reset_timepoints_2_params",
    "cifti_convert_reset_timepoints_params",
    "cifti_convert_to_gifti_ext_params",
    "cifti_convert_to_nifti_params",
    "cifti_convert_to_text_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_MODIFY_SPHERE_METADATA = Metadata(
    id="69965c5b4cd0399d7501f269ec55b50c372e008b.boutiques",
    name="surface-modify-sphere",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceModifySphereParameters = typing.TypedDict('SurfaceModifySphereParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-modify-sphere"]],
    "sphere_in": InputPathType,
    "radius": float,
    "sphere_out": str,
    "opt_recenter": bool,
})
SurfaceModifySphereParametersTagged = typing.TypedDict('SurfaceModifySphereParametersTagged', {
    "@type": typing.Literal["workbench/surface-modify-sphere"],
    "sphere_in": InputPathType,
    "radius": float,
    "sphere_out": str,
    "opt_recenter": bool,
})


class SurfaceModifySphereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceModifySphereParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sphere_out: OutputPathType
    """the output sphere"""


def surface_modify_sphere_params(
    sphere_in: InputPathType,
    radius: float,
    sphere_out: str,
    opt_recenter: bool = False,
) -> SurfaceModifySphereParametersTagged:
    """
    Build parameters.
    
    Args:
        sphere_in: the sphere to modify.
        radius: the radius the output sphere should have.
        sphere_out: the output sphere.
        opt_recenter: recenter the sphere by means of the bounding box.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-modify-sphere",
        "sphere_in": sphere_in,
        "radius": radius,
        "sphere_out": sphere_out,
        "opt_recenter": opt_recenter,
    }
    return params


def surface_modify_sphere_cargs(
    params: SurfaceModifySphereParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-modify-sphere")
    cargs.append(execution.input_file(params.get("sphere_in", None)))
    cargs.append(str(params.get("radius", None)))
    cargs.append(params.get("sphere_out", None))
    if params.get("opt_recenter", False):
        cargs.append("-recenter")
    return cargs


def surface_modify_sphere_outputs(
    params: SurfaceModifySphereParameters,
    execution: Execution,
) -> SurfaceModifySphereOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceModifySphereOutputs(
        root=execution.output_file("."),
        sphere_out=execution.output_file(params.get("sphere_out", None)),
    )
    return ret


def surface_modify_sphere_execute(
    params: SurfaceModifySphereParameters,
    runner: Runner | None = None,
) -> SurfaceModifySphereOutputs:
    """
    surface-modify-sphere
    
    Change radius and optionally recenter a sphere.
    
    This command may be useful if you have used -surface-resample to resample a
    sphere, which can suffer from problems generally not present in
    -surface-sphere-project-unproject. If the sphere should already be centered
    around the origin, using -recenter may still shift it slightly before
    changing the radius, which is likely to be undesireable.
    
    If <sphere-in> is not close to spherical, or not centered around the origin
    and -recenter is not used, a warning is printed.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceModifySphereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_MODIFY_SPHERE_METADATA)
    params = execution.params(params)
    cargs = surface_modify_sphere_cargs(params, execution)
    ret = surface_modify_sphere_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_modify_sphere(
    sphere_in: InputPathType,
    radius: float,
    sphere_out: str,
    opt_recenter: bool = False,
    runner: Runner | None = None,
) -> SurfaceModifySphereOutputs:
    """
    surface-modify-sphere
    
    Change radius and optionally recenter a sphere.
    
    This command may be useful if you have used -surface-resample to resample a
    sphere, which can suffer from problems generally not present in
    -surface-sphere-project-unproject. If the sphere should already be centered
    around the origin, using -recenter may still shift it slightly before
    changing the radius, which is likely to be undesireable.
    
    If <sphere-in> is not close to spherical, or not centered around the origin
    and -recenter is not used, a warning is printed.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        sphere_in: the sphere to modify.
        radius: the radius the output sphere should have.
        sphere_out: the output sphere.
        opt_recenter: recenter the sphere by means of the bounding box.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceModifySphereOutputs`).
    """
    params = surface_modify_sphere_params(
        sphere_in=sphere_in,
        radius=radius,
        sphere_out=sphere_out,
        opt_recenter=opt_recenter,
    )
    return surface_modify_sphere_execute(params, runner)


__all__ = [
    "SURFACE_MODIFY_SPHERE_METADATA",
    "SurfaceModifySphereOutputs",
    "surface_modify_sphere",
    "surface_modify_sphere_execute",
    "surface_modify_sphere_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_REDUCE_METADATA = Metadata(
    id="b2718ba70f250a6a0f620b99082f70f83dcd9fe0.boutiques",
    name="volume-reduce",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeReduceExcludeOutliersParameters = typing.TypedDict('VolumeReduceExcludeOutliersParameters', {
    "@type": typing.NotRequired[typing.Literal["exclude_outliers"]],
    "sigma_below": float,
    "sigma_above": float,
})
VolumeReduceExcludeOutliersParametersTagged = typing.TypedDict('VolumeReduceExcludeOutliersParametersTagged', {
    "@type": typing.Literal["exclude_outliers"],
    "sigma_below": float,
    "sigma_above": float,
})


VolumeReduceParameters = typing.TypedDict('VolumeReduceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-reduce"]],
    "volume_in": InputPathType,
    "operation": str,
    "volume_out": str,
    "exclude_outliers": typing.NotRequired[VolumeReduceExcludeOutliersParameters | None],
    "opt_only_numeric": bool,
})
VolumeReduceParametersTagged = typing.TypedDict('VolumeReduceParametersTagged', {
    "@type": typing.Literal["workbench/volume-reduce"],
    "volume_in": InputPathType,
    "operation": str,
    "volume_out": str,
    "exclude_outliers": typing.NotRequired[VolumeReduceExcludeOutliersParameters | None],
    "opt_only_numeric": bool,
})


def volume_reduce_exclude_outliers_params(
    sigma_below: float,
    sigma_above: float,
) -> VolumeReduceExcludeOutliersParametersTagged:
    """
    Build parameters.
    
    Args:
        sigma_below: number of standard deviations below the mean to include.
        sigma_above: number of standard deviations above the mean to include.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "exclude_outliers",
        "sigma_below": sigma_below,
        "sigma_above": sigma_above,
    }
    return params


def volume_reduce_exclude_outliers_cargs(
    params: VolumeReduceExcludeOutliersParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-exclude-outliers")
    cargs.append(str(params.get("sigma_below", None)))
    cargs.append(str(params.get("sigma_above", None)))
    return cargs


class VolumeReduceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeReduceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_reduce_params(
    volume_in: InputPathType,
    operation: str,
    volume_out: str,
    exclude_outliers: VolumeReduceExcludeOutliersParameters | None = None,
    opt_only_numeric: bool = False,
) -> VolumeReduceParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the volume file to reduce.
        operation: the reduction operator to use.
        volume_out: the output volume.
        exclude_outliers: exclude non-numeric values and outliers by standard\
            deviation.
        opt_only_numeric: exclude non-numeric values.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-reduce",
        "volume_in": volume_in,
        "operation": operation,
        "volume_out": volume_out,
        "opt_only_numeric": opt_only_numeric,
    }
    if exclude_outliers is not None:
        params["exclude_outliers"] = exclude_outliers
    return params


def volume_reduce_cargs(
    params: VolumeReduceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-reduce")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(params.get("operation", None))
    cargs.append(params.get("volume_out", None))
    if params.get("exclude_outliers", None) is not None:
        cargs.extend(volume_reduce_exclude_outliers_cargs(params.get("exclude_outliers", None), execution))
    if params.get("opt_only_numeric", False):
        cargs.append("-only-numeric")
    return cargs


def volume_reduce_outputs(
    params: VolumeReduceParameters,
    execution: Execution,
) -> VolumeReduceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeReduceOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_reduce_execute(
    params: VolumeReduceParameters,
    runner: Runner | None = None,
) -> VolumeReduceOutputs:
    """
    volume-reduce
    
    Perform reduction operation across subvolumes.
    
    For each voxel, takes the data across subvolumes as a vector, and performs
    the specified reduction on it, putting the result into the single output
    volume at that voxel. The reduction operators are as follows:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeReduceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_REDUCE_METADATA)
    params = execution.params(params)
    cargs = volume_reduce_cargs(params, execution)
    ret = volume_reduce_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_reduce(
    volume_in: InputPathType,
    operation: str,
    volume_out: str,
    exclude_outliers: VolumeReduceExcludeOutliersParameters | None = None,
    opt_only_numeric: bool = False,
    runner: Runner | None = None,
) -> VolumeReduceOutputs:
    """
    volume-reduce
    
    Perform reduction operation across subvolumes.
    
    For each voxel, takes the data across subvolumes as a vector, and performs
    the specified reduction on it, putting the result into the single output
    volume at that voxel. The reduction operators are as follows:
    
    MAX: the maximum value
    MIN: the minimum value
    INDEXMAX: the 1-based index of the maximum value
    INDEXMIN: the 1-based index of the minimum value
    SUM: add all values
    PRODUCT: multiply all values
    MEAN: the mean of the data
    STDEV: the standard deviation (N denominator)
    SAMPSTDEV: the sample standard deviation (N-1 denominator)
    VARIANCE: the variance of the data
    TSNR: mean divided by sample standard deviation (N-1 denominator)
    COV: sample standard deviation (N-1 denominator) divided by mean
    L2NORM: square root of sum of squares
    MEDIAN: the median of the data
    MODE: the mode of the data
    COUNT_NONZERO: the number of nonzero elements in the data
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the volume file to reduce.
        operation: the reduction operator to use.
        volume_out: the output volume.
        exclude_outliers: exclude non-numeric values and outliers by standard\
            deviation.
        opt_only_numeric: exclude non-numeric values.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeReduceOutputs`).
    """
    params = volume_reduce_params(
        volume_in=volume_in,
        operation=operation,
        volume_out=volume_out,
        exclude_outliers=exclude_outliers,
        opt_only_numeric=opt_only_numeric,
    )
    return volume_reduce_execute(params, runner)


__all__ = [
    "VOLUME_REDUCE_METADATA",
    "VolumeReduceOutputs",
    "volume_reduce",
    "volume_reduce_exclude_outliers_params",
    "volume_reduce_execute",
    "volume_reduce_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_SPHERE_TRIANGULAR_PATCHES_METADATA = Metadata(
    id="cb66e6f1207807e8529312a550ed72acdff594ee.boutiques",
    name="surface-sphere-triangular-patches",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceSphereTriangularPatchesParameters = typing.TypedDict('SurfaceSphereTriangularPatchesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-sphere-triangular-patches"]],
    "sphere": InputPathType,
    "divisions": int,
    "text_out": str,
})
SurfaceSphereTriangularPatchesParametersTagged = typing.TypedDict('SurfaceSphereTriangularPatchesParametersTagged', {
    "@type": typing.Literal["workbench/surface-sphere-triangular-patches"],
    "sphere": InputPathType,
    "divisions": int,
    "text_out": str,
})


class SurfaceSphereTriangularPatchesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceSphereTriangularPatchesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def surface_sphere_triangular_patches_params(
    sphere: InputPathType,
    divisions: int,
    text_out: str,
) -> SurfaceSphereTriangularPatchesParametersTagged:
    """
    Build parameters.
    
    Args:
        sphere: an undistorted, regularly divided icosahedral sphere.
        divisions: how many pieces to divide each icosahedral edge into, must\
            divide perfectly into the given sphere.
        text_out: output - text file for the vertex numbers of the patches.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-sphere-triangular-patches",
        "sphere": sphere,
        "divisions": divisions,
        "text_out": text_out,
    }
    return params


def surface_sphere_triangular_patches_cargs(
    params: SurfaceSphereTriangularPatchesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-sphere-triangular-patches")
    cargs.append(execution.input_file(params.get("sphere", None)))
    cargs.append(str(params.get("divisions", None)))
    cargs.append(params.get("text_out", None))
    return cargs


def surface_sphere_triangular_patches_outputs(
    params: SurfaceSphereTriangularPatchesParameters,
    execution: Execution,
) -> SurfaceSphereTriangularPatchesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceSphereTriangularPatchesOutputs(
        root=execution.output_file("."),
    )
    return ret


def surface_sphere_triangular_patches_execute(
    params: SurfaceSphereTriangularPatchesParameters,
    runner: Runner | None = None,
) -> SurfaceSphereTriangularPatchesOutputs:
    """
    surface-sphere-triangular-patches
    
    Divide standard sphere into patches.
    
    Divide the given undistorted sphere into equally-sized triangular patches.
    Patches overlap by a border of 1 vertex.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSphereTriangularPatchesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_SPHERE_TRIANGULAR_PATCHES_METADATA)
    params = execution.params(params)
    cargs = surface_sphere_triangular_patches_cargs(params, execution)
    ret = surface_sphere_triangular_patches_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_sphere_triangular_patches(
    sphere: InputPathType,
    divisions: int,
    text_out: str,
    runner: Runner | None = None,
) -> SurfaceSphereTriangularPatchesOutputs:
    """
    surface-sphere-triangular-patches
    
    Divide standard sphere into patches.
    
    Divide the given undistorted sphere into equally-sized triangular patches.
    Patches overlap by a border of 1 vertex.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        sphere: an undistorted, regularly divided icosahedral sphere.
        divisions: how many pieces to divide each icosahedral edge into, must\
            divide perfectly into the given sphere.
        text_out: output - text file for the vertex numbers of the patches.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSphereTriangularPatchesOutputs`).
    """
    params = surface_sphere_triangular_patches_params(
        sphere=sphere,
        divisions=divisions,
        text_out=text_out,
    )
    return surface_sphere_triangular_patches_execute(params, runner)


__all__ = [
    "SURFACE_SPHERE_TRIANGULAR_PATCHES_METADATA",
    "SurfaceSphereTriangularPatchesOutputs",
    "surface_sphere_triangular_patches",
    "surface_sphere_triangular_patches_execute",
    "surface_sphere_triangular_patches_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_DISTORTION_METADATA = Metadata(
    id="fa15f46e1a24623dca8c79bbbc906531f7c5b4c3.boutiques",
    name="surface-distortion",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceDistortionSmoothParameters = typing.TypedDict('SurfaceDistortionSmoothParameters', {
    "@type": typing.NotRequired[typing.Literal["smooth"]],
    "sigma": float,
    "opt_fwhm": bool,
})
SurfaceDistortionSmoothParametersTagged = typing.TypedDict('SurfaceDistortionSmoothParametersTagged', {
    "@type": typing.Literal["smooth"],
    "sigma": float,
    "opt_fwhm": bool,
})


SurfaceDistortionLocalAffineMethodParameters = typing.TypedDict('SurfaceDistortionLocalAffineMethodParameters', {
    "@type": typing.NotRequired[typing.Literal["local_affine_method"]],
    "opt_log2": bool,
})
SurfaceDistortionLocalAffineMethodParametersTagged = typing.TypedDict('SurfaceDistortionLocalAffineMethodParametersTagged', {
    "@type": typing.Literal["local_affine_method"],
    "opt_log2": bool,
})


SurfaceDistortionParameters = typing.TypedDict('SurfaceDistortionParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-distortion"]],
    "surface_reference": InputPathType,
    "surface_distorted": InputPathType,
    "metric_out": str,
    "smooth": typing.NotRequired[SurfaceDistortionSmoothParameters | None],
    "opt_caret5_method": bool,
    "opt_edge_method": bool,
    "local_affine_method": typing.NotRequired[SurfaceDistortionLocalAffineMethodParameters | None],
})
SurfaceDistortionParametersTagged = typing.TypedDict('SurfaceDistortionParametersTagged', {
    "@type": typing.Literal["workbench/surface-distortion"],
    "surface_reference": InputPathType,
    "surface_distorted": InputPathType,
    "metric_out": str,
    "smooth": typing.NotRequired[SurfaceDistortionSmoothParameters | None],
    "opt_caret5_method": bool,
    "opt_edge_method": bool,
    "local_affine_method": typing.NotRequired[SurfaceDistortionLocalAffineMethodParameters | None],
})


def surface_distortion_smooth_params(
    sigma: float,
    opt_fwhm: bool = False,
) -> SurfaceDistortionSmoothParametersTagged:
    """
    Build parameters.
    
    Args:
        sigma: the size of the smoothing kernel in mm, as sigma by default.
        opt_fwhm: kernel size is FWHM, not sigma.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "smooth",
        "sigma": sigma,
        "opt_fwhm": opt_fwhm,
    }
    return params


def surface_distortion_smooth_cargs(
    params: SurfaceDistortionSmoothParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-smooth")
    cargs.append(str(params.get("sigma", None)))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    return cargs


def surface_distortion_local_affine_method_params(
    opt_log2: bool = False,
) -> SurfaceDistortionLocalAffineMethodParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_log2: apply base-2 log transform.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "local_affine_method",
        "opt_log2": opt_log2,
    }
    return params


def surface_distortion_local_affine_method_cargs(
    params: SurfaceDistortionLocalAffineMethodParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-local-affine-method")
    if params.get("opt_log2", False):
        cargs.append("-log2")
    return cargs


class SurfaceDistortionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceDistortionParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output distortion metric"""


def surface_distortion_params(
    surface_reference: InputPathType,
    surface_distorted: InputPathType,
    metric_out: str,
    smooth: SurfaceDistortionSmoothParameters | None = None,
    opt_caret5_method: bool = False,
    opt_edge_method: bool = False,
    local_affine_method: SurfaceDistortionLocalAffineMethodParameters | None = None,
) -> SurfaceDistortionParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_reference: the reference surface.
        surface_distorted: the distorted surface.
        metric_out: the output distortion metric.
        smooth: smooth the area data.
        opt_caret5_method: use the surface distortion method from caret5.
        opt_edge_method: calculate distortion of edge lengths rather than areas.
        local_affine_method: calculate distortion by the local affines between\
            triangles.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-distortion",
        "surface_reference": surface_reference,
        "surface_distorted": surface_distorted,
        "metric_out": metric_out,
        "opt_caret5_method": opt_caret5_method,
        "opt_edge_method": opt_edge_method,
    }
    if smooth is not None:
        params["smooth"] = smooth
    if local_affine_method is not None:
        params["local_affine_method"] = local_affine_method
    return params


def surface_distortion_cargs(
    params: SurfaceDistortionParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-distortion")
    cargs.append(execution.input_file(params.get("surface_reference", None)))
    cargs.append(execution.input_file(params.get("surface_distorted", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("smooth", None) is not None:
        cargs.extend(surface_distortion_smooth_cargs(params.get("smooth", None), execution))
    if params.get("opt_caret5_method", False):
        cargs.append("-caret5-method")
    if params.get("opt_edge_method", False):
        cargs.append("-edge-method")
    if params.get("local_affine_method", None) is not None:
        cargs.extend(surface_distortion_local_affine_method_cargs(params.get("local_affine_method", None), execution))
    return cargs


def surface_distortion_outputs(
    params: SurfaceDistortionParameters,
    execution: Execution,
) -> SurfaceDistortionOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceDistortionOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def surface_distortion_execute(
    params: SurfaceDistortionParameters,
    runner: Runner | None = None,
) -> SurfaceDistortionOutputs:
    """
    surface-distortion
    
    Measure distortion between surfaces.
    
    This command, when not using -caret5-method, -edge-method, or
    -local-affine-method, is equivalent to using -surface-vertex-areas on each
    surface, smoothing both output metrics with the GEO_GAUSS_EQUAL method on
    the surface they came from if -smooth is specified, and then using the
    formula 'ln(distorted/reference)/ln(2)' on the smoothed results.
    
    When using -caret5-method, it uses the surface distortion method from
    caret5, which takes the base 2 log of the ratio of tile areas, then averages
    those results at each vertex, and then smooths the result on the reference
    surface.
    
    When using -edge-method, the -smooth option is ignored, and the output at
    each vertex is the average of 'abs(ln(refEdge/distortEdge)/ln(2))' over all
    edges connected to the vertex.
    
    When using -local-affine-method, the -smooth option is ignored. The output
    is two columns, the first is the area distortion ratio, and the second is
    anisotropic strain. These are calculated by an affine transform between
    matching triangles, and then averaged across the triangles of a vertex.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceDistortionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_DISTORTION_METADATA)
    params = execution.params(params)
    cargs = surface_distortion_cargs(params, execution)
    ret = surface_distortion_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_distortion(
    surface_reference: InputPathType,
    surface_distorted: InputPathType,
    metric_out: str,
    smooth: SurfaceDistortionSmoothParameters | None = None,
    opt_caret5_method: bool = False,
    opt_edge_method: bool = False,
    local_affine_method: SurfaceDistortionLocalAffineMethodParameters | None = None,
    runner: Runner | None = None,
) -> SurfaceDistortionOutputs:
    """
    surface-distortion
    
    Measure distortion between surfaces.
    
    This command, when not using -caret5-method, -edge-method, or
    -local-affine-method, is equivalent to using -surface-vertex-areas on each
    surface, smoothing both output metrics with the GEO_GAUSS_EQUAL method on
    the surface they came from if -smooth is specified, and then using the
    formula 'ln(distorted/reference)/ln(2)' on the smoothed results.
    
    When using -caret5-method, it uses the surface distortion method from
    caret5, which takes the base 2 log of the ratio of tile areas, then averages
    those results at each vertex, and then smooths the result on the reference
    surface.
    
    When using -edge-method, the -smooth option is ignored, and the output at
    each vertex is the average of 'abs(ln(refEdge/distortEdge)/ln(2))' over all
    edges connected to the vertex.
    
    When using -local-affine-method, the -smooth option is ignored. The output
    is two columns, the first is the area distortion ratio, and the second is
    anisotropic strain. These are calculated by an affine transform between
    matching triangles, and then averaged across the triangles of a vertex.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_reference: the reference surface.
        surface_distorted: the distorted surface.
        metric_out: the output distortion metric.
        smooth: smooth the area data.
        opt_caret5_method: use the surface distortion method from caret5.
        opt_edge_method: calculate distortion of edge lengths rather than areas.
        local_affine_method: calculate distortion by the local affines between\
            triangles.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceDistortionOutputs`).
    """
    params = surface_distortion_params(
        surface_reference=surface_reference,
        surface_distorted=surface_distorted,
        metric_out=metric_out,
        smooth=smooth,
        opt_caret5_method=opt_caret5_method,
        opt_edge_method=opt_edge_method,
        local_affine_method=local_affine_method,
    )
    return surface_distortion_execute(params, runner)


__all__ = [
    "SURFACE_DISTORTION_METADATA",
    "SurfaceDistortionOutputs",
    "surface_distortion",
    "surface_distortion_execute",
    "surface_distortion_local_affine_method_params",
    "surface_distortion_params",
    "surface_distortion_smooth_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_WEIGHTED_STATS_METADATA = Metadata(
    id="c29a27c55897b9b33cfccfdd394f55a82bf8f22f.boutiques",
    name="cifti-weighted-stats",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiWeightedStatsSpatialWeightsParameters = typing.TypedDict('CiftiWeightedStatsSpatialWeightsParameters', {
    "@type": typing.NotRequired[typing.Literal["spatial_weights"]],
    "opt_left_area_surf_left_surf": typing.NotRequired[InputPathType | None],
    "opt_right_area_surf_right_surf": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_area_surf_cerebellum_surf": typing.NotRequired[InputPathType | None],
    "opt_left_area_metric_left_metric": typing.NotRequired[InputPathType | None],
    "opt_right_area_metric_right_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_area_metric_cerebellum_metric": typing.NotRequired[InputPathType | None],
})
CiftiWeightedStatsSpatialWeightsParametersTagged = typing.TypedDict('CiftiWeightedStatsSpatialWeightsParametersTagged', {
    "@type": typing.Literal["spatial_weights"],
    "opt_left_area_surf_left_surf": typing.NotRequired[InputPathType | None],
    "opt_right_area_surf_right_surf": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_area_surf_cerebellum_surf": typing.NotRequired[InputPathType | None],
    "opt_left_area_metric_left_metric": typing.NotRequired[InputPathType | None],
    "opt_right_area_metric_right_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_area_metric_cerebellum_metric": typing.NotRequired[InputPathType | None],
})


CiftiWeightedStatsRoiParameters = typing.TypedDict('CiftiWeightedStatsRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["roi"]],
    "roi_cifti": InputPathType,
    "opt_match_maps": bool,
})
CiftiWeightedStatsRoiParametersTagged = typing.TypedDict('CiftiWeightedStatsRoiParametersTagged', {
    "@type": typing.Literal["roi"],
    "roi_cifti": InputPathType,
    "opt_match_maps": bool,
})


CiftiWeightedStatsStdevParameters = typing.TypedDict('CiftiWeightedStatsStdevParameters', {
    "@type": typing.NotRequired[typing.Literal["stdev"]],
    "opt_sample": bool,
})
CiftiWeightedStatsStdevParametersTagged = typing.TypedDict('CiftiWeightedStatsStdevParametersTagged', {
    "@type": typing.Literal["stdev"],
    "opt_sample": bool,
})


CiftiWeightedStatsParameters = typing.TypedDict('CiftiWeightedStatsParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-weighted-stats"]],
    "cifti_in": InputPathType,
    "spatial_weights": typing.NotRequired[CiftiWeightedStatsSpatialWeightsParameters | None],
    "opt_cifti_weights_weight_cifti": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[int | None],
    "roi": typing.NotRequired[CiftiWeightedStatsRoiParameters | None],
    "opt_mean": bool,
    "stdev": typing.NotRequired[CiftiWeightedStatsStdevParameters | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_sum": bool,
    "opt_show_map_name": bool,
})
CiftiWeightedStatsParametersTagged = typing.TypedDict('CiftiWeightedStatsParametersTagged', {
    "@type": typing.Literal["workbench/cifti-weighted-stats"],
    "cifti_in": InputPathType,
    "spatial_weights": typing.NotRequired[CiftiWeightedStatsSpatialWeightsParameters | None],
    "opt_cifti_weights_weight_cifti": typing.NotRequired[InputPathType | None],
    "opt_column_column": typing.NotRequired[int | None],
    "roi": typing.NotRequired[CiftiWeightedStatsRoiParameters | None],
    "opt_mean": bool,
    "stdev": typing.NotRequired[CiftiWeightedStatsStdevParameters | None],
    "opt_percentile_percent": typing.NotRequired[float | None],
    "opt_sum": bool,
    "opt_show_map_name": bool,
})


def cifti_weighted_stats_spatial_weights_params(
    opt_left_area_surf_left_surf: InputPathType | None = None,
    opt_right_area_surf_right_surf: InputPathType | None = None,
    opt_cerebellum_area_surf_cerebellum_surf: InputPathType | None = None,
    opt_left_area_metric_left_metric: InputPathType | None = None,
    opt_right_area_metric_right_metric: InputPathType | None = None,
    opt_cerebellum_area_metric_cerebellum_metric: InputPathType | None = None,
) -> CiftiWeightedStatsSpatialWeightsParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_left_area_surf_left_surf: use a surface for left vertex areas: the\
            left surface to use, areas are in mm^2.
        opt_right_area_surf_right_surf: use a surface for right vertex areas:\
            the right surface to use, areas are in mm^2.
        opt_cerebellum_area_surf_cerebellum_surf: use a surface for cerebellum\
            vertex areas: the cerebellum surface to use, areas are in mm^2.
        opt_left_area_metric_left_metric: use a metric file for left vertex\
            areas: metric file containing left vertex areas.
        opt_right_area_metric_right_metric: use a metric file for right vertex\
            areas: metric file containing right vertex areas.
        opt_cerebellum_area_metric_cerebellum_metric: use a metric file for\
            cerebellum vertex areas: metric file containing cerebellum vertex areas.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "spatial_weights",
    }
    if opt_left_area_surf_left_surf is not None:
        params["opt_left_area_surf_left_surf"] = opt_left_area_surf_left_surf
    if opt_right_area_surf_right_surf is not None:
        params["opt_right_area_surf_right_surf"] = opt_right_area_surf_right_surf
    if opt_cerebellum_area_surf_cerebellum_surf is not None:
        params["opt_cerebellum_area_surf_cerebellum_surf"] = opt_cerebellum_area_surf_cerebellum_surf
    if opt_left_area_metric_left_metric is not None:
        params["opt_left_area_metric_left_metric"] = opt_left_area_metric_left_metric
    if opt_right_area_metric_right_metric is not None:
        params["opt_right_area_metric_right_metric"] = opt_right_area_metric_right_metric
    if opt_cerebellum_area_metric_cerebellum_metric is not None:
        params["opt_cerebellum_area_metric_cerebellum_metric"] = opt_cerebellum_area_metric_cerebellum_metric
    return params


def cifti_weighted_stats_spatial_weights_cargs(
    params: CiftiWeightedStatsSpatialWeightsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-spatial-weights")
    if params.get("opt_left_area_surf_left_surf", None) is not None:
        cargs.extend([
            "-left-area-surf",
            execution.input_file(params.get("opt_left_area_surf_left_surf", None))
        ])
    if params.get("opt_right_area_surf_right_surf", None) is not None:
        cargs.extend([
            "-right-area-surf",
            execution.input_file(params.get("opt_right_area_surf_right_surf", None))
        ])
    if params.get("opt_cerebellum_area_surf_cerebellum_surf", None) is not None:
        cargs.extend([
            "-cerebellum-area-surf",
            execution.input_file(params.get("opt_cerebellum_area_surf_cerebellum_surf", None))
        ])
    if params.get("opt_left_area_metric_left_metric", None) is not None:
        cargs.extend([
            "-left-area-metric",
            execution.input_file(params.get("opt_left_area_metric_left_metric", None))
        ])
    if params.get("opt_right_area_metric_right_metric", None) is not None:
        cargs.extend([
            "-right-area-metric",
            execution.input_file(params.get("opt_right_area_metric_right_metric", None))
        ])
    if params.get("opt_cerebellum_area_metric_cerebellum_metric", None) is not None:
        cargs.extend([
            "-cerebellum-area-metric",
            execution.input_file(params.get("opt_cerebellum_area_metric_cerebellum_metric", None))
        ])
    return cargs


def cifti_weighted_stats_roi_params(
    roi_cifti: InputPathType,
    opt_match_maps: bool = False,
) -> CiftiWeightedStatsRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        roi_cifti: the roi, as a cifti file.
        opt_match_maps: each column of input uses the corresponding column from\
            the roi file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "roi",
        "roi_cifti": roi_cifti,
        "opt_match_maps": opt_match_maps,
    }
    return params


def cifti_weighted_stats_roi_cargs(
    params: CiftiWeightedStatsRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-roi")
    cargs.append(execution.input_file(params.get("roi_cifti", None)))
    if params.get("opt_match_maps", False):
        cargs.append("-match-maps")
    return cargs


def cifti_weighted_stats_stdev_params(
    opt_sample: bool = False,
) -> CiftiWeightedStatsStdevParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_sample: estimate population stdev from the sample.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "stdev",
        "opt_sample": opt_sample,
    }
    return params


def cifti_weighted_stats_stdev_cargs(
    params: CiftiWeightedStatsStdevParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-stdev")
    if params.get("opt_sample", False):
        cargs.append("-sample")
    return cargs


class CiftiWeightedStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiWeightedStatsParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_weighted_stats_params(
    cifti_in: InputPathType,
    spatial_weights: CiftiWeightedStatsSpatialWeightsParameters | None = None,
    opt_cifti_weights_weight_cifti: InputPathType | None = None,
    opt_column_column: int | None = None,
    roi: CiftiWeightedStatsRoiParameters | None = None,
    opt_mean: bool = False,
    stdev: CiftiWeightedStatsStdevParameters | None = None,
    opt_percentile_percent: float | None = None,
    opt_sum: bool = False,
    opt_show_map_name: bool = False,
) -> CiftiWeightedStatsParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti.
        spatial_weights: use vertex area and voxel volume as weights.
        opt_cifti_weights_weight_cifti: use a cifti file containing weights:\
            the weights to use, as a cifti file.
        opt_column_column: only display output for one column: the column to\
            use (1-based).
        roi: only consider data inside an roi.
        opt_mean: compute weighted mean.
        stdev: compute weighted standard deviation.
        opt_percentile_percent: compute weighted percentile: the percentile to\
            find, must be between 0 and 100.
        opt_sum: compute weighted sum.
        opt_show_map_name: print map index and name before each output.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-weighted-stats",
        "cifti_in": cifti_in,
        "opt_mean": opt_mean,
        "opt_sum": opt_sum,
        "opt_show_map_name": opt_show_map_name,
    }
    if spatial_weights is not None:
        params["spatial_weights"] = spatial_weights
    if opt_cifti_weights_weight_cifti is not None:
        params["opt_cifti_weights_weight_cifti"] = opt_cifti_weights_weight_cifti
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if roi is not None:
        params["roi"] = roi
    if stdev is not None:
        params["stdev"] = stdev
    if opt_percentile_percent is not None:
        params["opt_percentile_percent"] = opt_percentile_percent
    return params


def cifti_weighted_stats_cargs(
    params: CiftiWeightedStatsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-weighted-stats")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    if params.get("spatial_weights", None) is not None:
        cargs.extend(cifti_weighted_stats_spatial_weights_cargs(params.get("spatial_weights", None), execution))
    if params.get("opt_cifti_weights_weight_cifti", None) is not None:
        cargs.extend([
            "-cifti-weights",
            execution.input_file(params.get("opt_cifti_weights_weight_cifti", None))
        ])
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            str(params.get("opt_column_column", None))
        ])
    if params.get("roi", None) is not None:
        cargs.extend(cifti_weighted_stats_roi_cargs(params.get("roi", None), execution))
    if params.get("opt_mean", False):
        cargs.append("-mean")
    if params.get("stdev", None) is not None:
        cargs.extend(cifti_weighted_stats_stdev_cargs(params.get("stdev", None), execution))
    if params.get("opt_percentile_percent", None) is not None:
        cargs.extend([
            "-percentile",
            str(params.get("opt_percentile_percent", None))
        ])
    if params.get("opt_sum", False):
        cargs.append("-sum")
    if params.get("opt_show_map_name", False):
        cargs.append("-show-map-name")
    return cargs


def cifti_weighted_stats_outputs(
    params: CiftiWeightedStatsParameters,
    execution: Execution,
) -> CiftiWeightedStatsOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiWeightedStatsOutputs(
        root=execution.output_file("."),
    )
    return ret


def cifti_weighted_stats_execute(
    params: CiftiWeightedStatsParameters,
    runner: Runner | None = None,
) -> CiftiWeightedStatsOutputs:
    """
    cifti-weighted-stats
    
    Weighted statistics along cifti columns.
    
    If the mapping along column is brain models, for each column of the input,
    the specified operation is done on each surface and across all voxels, and
    the results are printed on separate lines. For other mapping types, the
    operation is done on each column, and one line per map is printed. Exactly
    one of -spatial-weights or -cifti-weights must be specified. Use -column to
    only give output for a single column. If the -roi option is used without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Exactly one of -mean, -stdev,
    -percentile or -sum must be specified.
    
    Using -sum with -spatial-weights (or with -cifti-weights and a cifti
    containing weights of similar meaning) is equivalent to integrating with
    respect to area and volume. When the input is binary ROIs, this will
    therefore output the area or volume of each ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiWeightedStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_WEIGHTED_STATS_METADATA)
    params = execution.params(params)
    cargs = cifti_weighted_stats_cargs(params, execution)
    ret = cifti_weighted_stats_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_weighted_stats(
    cifti_in: InputPathType,
    spatial_weights: CiftiWeightedStatsSpatialWeightsParameters | None = None,
    opt_cifti_weights_weight_cifti: InputPathType | None = None,
    opt_column_column: int | None = None,
    roi: CiftiWeightedStatsRoiParameters | None = None,
    opt_mean: bool = False,
    stdev: CiftiWeightedStatsStdevParameters | None = None,
    opt_percentile_percent: float | None = None,
    opt_sum: bool = False,
    opt_show_map_name: bool = False,
    runner: Runner | None = None,
) -> CiftiWeightedStatsOutputs:
    """
    cifti-weighted-stats
    
    Weighted statistics along cifti columns.
    
    If the mapping along column is brain models, for each column of the input,
    the specified operation is done on each surface and across all voxels, and
    the results are printed on separate lines. For other mapping types, the
    operation is done on each column, and one line per map is printed. Exactly
    one of -spatial-weights or -cifti-weights must be specified. Use -column to
    only give output for a single column. If the -roi option is used without
    -match-maps, then each line will contain as many numbers as there are maps
    in the ROI file, separated by tab characters. Exactly one of -mean, -stdev,
    -percentile or -sum must be specified.
    
    Using -sum with -spatial-weights (or with -cifti-weights and a cifti
    containing weights of similar meaning) is equivalent to integrating with
    respect to area and volume. When the input is binary ROIs, this will
    therefore output the area or volume of each ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti.
        spatial_weights: use vertex area and voxel volume as weights.
        opt_cifti_weights_weight_cifti: use a cifti file containing weights:\
            the weights to use, as a cifti file.
        opt_column_column: only display output for one column: the column to\
            use (1-based).
        roi: only consider data inside an roi.
        opt_mean: compute weighted mean.
        stdev: compute weighted standard deviation.
        opt_percentile_percent: compute weighted percentile: the percentile to\
            find, must be between 0 and 100.
        opt_sum: compute weighted sum.
        opt_show_map_name: print map index and name before each output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiWeightedStatsOutputs`).
    """
    params = cifti_weighted_stats_params(
        cifti_in=cifti_in,
        spatial_weights=spatial_weights,
        opt_cifti_weights_weight_cifti=opt_cifti_weights_weight_cifti,
        opt_column_column=opt_column_column,
        roi=roi,
        opt_mean=opt_mean,
        stdev=stdev,
        opt_percentile_percent=opt_percentile_percent,
        opt_sum=opt_sum,
        opt_show_map_name=opt_show_map_name,
    )
    return cifti_weighted_stats_execute(params, runner)


__all__ = [
    "CIFTI_WEIGHTED_STATS_METADATA",
    "CiftiWeightedStatsOutputs",
    "cifti_weighted_stats",
    "cifti_weighted_stats_execute",
    "cifti_weighted_stats_params",
    "cifti_weighted_stats_roi_params",
    "cifti_weighted_stats_spatial_weights_params",
    "cifti_weighted_stats_stdev_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_LABEL_TO_ROI_METADATA = Metadata(
    id="404b13c7f6d3d80cd95caa08b411c3b50061d9cb.boutiques",
    name="cifti-label-to-roi",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiLabelToRoiParameters = typing.TypedDict('CiftiLabelToRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-label-to-roi"]],
    "label_in": InputPathType,
    "scalar_out": str,
    "opt_name_label_name": typing.NotRequired[str | None],
    "opt_key_label_key": typing.NotRequired[int | None],
    "opt_map_map": typing.NotRequired[str | None],
})
CiftiLabelToRoiParametersTagged = typing.TypedDict('CiftiLabelToRoiParametersTagged', {
    "@type": typing.Literal["workbench/cifti-label-to-roi"],
    "label_in": InputPathType,
    "scalar_out": str,
    "opt_name_label_name": typing.NotRequired[str | None],
    "opt_key_label_key": typing.NotRequired[int | None],
    "opt_map_map": typing.NotRequired[str | None],
})


class CiftiLabelToRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiLabelToRoiParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    scalar_out: OutputPathType
    """the output cifti scalar file"""


def cifti_label_to_roi_params(
    label_in: InputPathType,
    scalar_out: str,
    opt_name_label_name: str | None = None,
    opt_key_label_key: int | None = None,
    opt_map_map: str | None = None,
) -> CiftiLabelToRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the input cifti label file.
        scalar_out: the output cifti scalar file.
        opt_name_label_name: select label by name: the label name that you want\
            an roi of.
        opt_key_label_key: select label by key: the label key that you want an\
            roi of.
        opt_map_map: select a single label map to use: the map number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-label-to-roi",
        "label_in": label_in,
        "scalar_out": scalar_out,
    }
    if opt_name_label_name is not None:
        params["opt_name_label_name"] = opt_name_label_name
    if opt_key_label_key is not None:
        params["opt_key_label_key"] = opt_key_label_key
    if opt_map_map is not None:
        params["opt_map_map"] = opt_map_map
    return params


def cifti_label_to_roi_cargs(
    params: CiftiLabelToRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-label-to-roi")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(params.get("scalar_out", None))
    if params.get("opt_name_label_name", None) is not None:
        cargs.extend([
            "-name",
            params.get("opt_name_label_name", None)
        ])
    if params.get("opt_key_label_key", None) is not None:
        cargs.extend([
            "-key",
            str(params.get("opt_key_label_key", None))
        ])
    if params.get("opt_map_map", None) is not None:
        cargs.extend([
            "-map",
            params.get("opt_map_map", None)
        ])
    return cargs


def cifti_label_to_roi_outputs(
    params: CiftiLabelToRoiParameters,
    execution: Execution,
) -> CiftiLabelToRoiOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiLabelToRoiOutputs(
        root=execution.output_file("."),
        scalar_out=execution.output_file(params.get("scalar_out", None)),
    )
    return ret


def cifti_label_to_roi_execute(
    params: CiftiLabelToRoiParameters,
    runner: Runner | None = None,
) -> CiftiLabelToRoiOutputs:
    """
    cifti-label-to-roi
    
    Make a cifti label into an roi.
    
    For each map in <label-in>, a map is created in <scalar-out> where all
    locations labeled with <label-name> or with a key of <label-key> are given a
    value of 1, and all other locations are given 0. Exactly one of -name and
    -key must be specified. Specify -map to use only one map from <label-in>.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelToRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_LABEL_TO_ROI_METADATA)
    params = execution.params(params)
    cargs = cifti_label_to_roi_cargs(params, execution)
    ret = cifti_label_to_roi_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_label_to_roi(
    label_in: InputPathType,
    scalar_out: str,
    opt_name_label_name: str | None = None,
    opt_key_label_key: int | None = None,
    opt_map_map: str | None = None,
    runner: Runner | None = None,
) -> CiftiLabelToRoiOutputs:
    """
    cifti-label-to-roi
    
    Make a cifti label into an roi.
    
    For each map in <label-in>, a map is created in <scalar-out> where all
    locations labeled with <label-name> or with a key of <label-key> are given a
    value of 1, and all other locations are given 0. Exactly one of -name and
    -key must be specified. Specify -map to use only one map from <label-in>.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input cifti label file.
        scalar_out: the output cifti scalar file.
        opt_name_label_name: select label by name: the label name that you want\
            an roi of.
        opt_key_label_key: select label by key: the label key that you want an\
            roi of.
        opt_map_map: select a single label map to use: the map number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiLabelToRoiOutputs`).
    """
    params = cifti_label_to_roi_params(
        label_in=label_in,
        scalar_out=scalar_out,
        opt_name_label_name=opt_name_label_name,
        opt_key_label_key=opt_key_label_key,
        opt_map_map=opt_map_map,
    )
    return cifti_label_to_roi_execute(params, runner)


__all__ = [
    "CIFTI_LABEL_TO_ROI_METADATA",
    "CiftiLabelToRoiOutputs",
    "cifti_label_to_roi",
    "cifti_label_to_roi_execute",
    "cifti_label_to_roi_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_PALETTE_METADATA = Metadata(
    id="060ccaaa0889c06957231f056645f3e123168bef.boutiques",
    name="metric-palette",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricPalettePosPercentParameters = typing.TypedDict('MetricPalettePosPercentParameters', {
    "@type": typing.NotRequired[typing.Literal["pos_percent"]],
    "pos_min__": float,
    "pos_max__": float,
})
MetricPalettePosPercentParametersTagged = typing.TypedDict('MetricPalettePosPercentParametersTagged', {
    "@type": typing.Literal["pos_percent"],
    "pos_min__": float,
    "pos_max__": float,
})


MetricPaletteNegPercentParameters = typing.TypedDict('MetricPaletteNegPercentParameters', {
    "@type": typing.NotRequired[typing.Literal["neg_percent"]],
    "neg_min__": float,
    "neg_max__": float,
})
MetricPaletteNegPercentParametersTagged = typing.TypedDict('MetricPaletteNegPercentParametersTagged', {
    "@type": typing.Literal["neg_percent"],
    "neg_min__": float,
    "neg_max__": float,
})


MetricPalettePosUserParameters = typing.TypedDict('MetricPalettePosUserParameters', {
    "@type": typing.NotRequired[typing.Literal["pos_user"]],
    "pos_min_user": float,
    "pos_max_user": float,
})
MetricPalettePosUserParametersTagged = typing.TypedDict('MetricPalettePosUserParametersTagged', {
    "@type": typing.Literal["pos_user"],
    "pos_min_user": float,
    "pos_max_user": float,
})


MetricPaletteNegUserParameters = typing.TypedDict('MetricPaletteNegUserParameters', {
    "@type": typing.NotRequired[typing.Literal["neg_user"]],
    "neg_min_user": float,
    "neg_max_user": float,
})
MetricPaletteNegUserParametersTagged = typing.TypedDict('MetricPaletteNegUserParametersTagged', {
    "@type": typing.Literal["neg_user"],
    "neg_min_user": float,
    "neg_max_user": float,
})


MetricPaletteThresholdingParameters = typing.TypedDict('MetricPaletteThresholdingParameters', {
    "@type": typing.NotRequired[typing.Literal["thresholding"]],
    "type": str,
    "test": str,
    "min": float,
    "max": float,
})
MetricPaletteThresholdingParametersTagged = typing.TypedDict('MetricPaletteThresholdingParametersTagged', {
    "@type": typing.Literal["thresholding"],
    "type": str,
    "test": str,
    "min": float,
    "max": float,
})


MetricPaletteParameters = typing.TypedDict('MetricPaletteParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-palette"]],
    "metric": str,
    "mode": str,
    "opt_column_column": typing.NotRequired[str | None],
    "pos_percent": typing.NotRequired[MetricPalettePosPercentParameters | None],
    "neg_percent": typing.NotRequired[MetricPaletteNegPercentParameters | None],
    "pos_user": typing.NotRequired[MetricPalettePosUserParameters | None],
    "neg_user": typing.NotRequired[MetricPaletteNegUserParameters | None],
    "opt_interpolate_interpolate": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_pos_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_neg_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_zero_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_palette_name_name": typing.NotRequired[str | None],
    "thresholding": typing.NotRequired[MetricPaletteThresholdingParameters | None],
    "opt_inversion_type": typing.NotRequired[str | None],
})
MetricPaletteParametersTagged = typing.TypedDict('MetricPaletteParametersTagged', {
    "@type": typing.Literal["workbench/metric-palette"],
    "metric": str,
    "mode": str,
    "opt_column_column": typing.NotRequired[str | None],
    "pos_percent": typing.NotRequired[MetricPalettePosPercentParameters | None],
    "neg_percent": typing.NotRequired[MetricPaletteNegPercentParameters | None],
    "pos_user": typing.NotRequired[MetricPalettePosUserParameters | None],
    "neg_user": typing.NotRequired[MetricPaletteNegUserParameters | None],
    "opt_interpolate_interpolate": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_pos_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_neg_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_disp_zero_display": typing.NotRequired[typing.Literal["true", "false"] | None],
    "opt_palette_name_name": typing.NotRequired[str | None],
    "thresholding": typing.NotRequired[MetricPaletteThresholdingParameters | None],
    "opt_inversion_type": typing.NotRequired[str | None],
})


def metric_palette_pos_percent_params(
    pos_min__: float,
    pos_max__: float,
) -> MetricPalettePosPercentParametersTagged:
    """
    Build parameters.
    
    Args:
        pos_min__: the percentile for the least positive data.
        pos_max__: the percentile for the most positive data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "pos_percent",
        "pos_min__": pos_min__,
        "pos_max__": pos_max__,
    }
    return params


def metric_palette_pos_percent_cargs(
    params: MetricPalettePosPercentParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-pos-percent")
    cargs.append(str(params.get("pos_min__", None)))
    cargs.append(str(params.get("pos_max__", None)))
    return cargs


def metric_palette_neg_percent_params(
    neg_min__: float,
    neg_max__: float,
) -> MetricPaletteNegPercentParametersTagged:
    """
    Build parameters.
    
    Args:
        neg_min__: the percentile for the least negative data.
        neg_max__: the percentile for the most negative data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "neg_percent",
        "neg_min__": neg_min__,
        "neg_max__": neg_max__,
    }
    return params


def metric_palette_neg_percent_cargs(
    params: MetricPaletteNegPercentParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-neg-percent")
    cargs.append(str(params.get("neg_min__", None)))
    cargs.append(str(params.get("neg_max__", None)))
    return cargs


def metric_palette_pos_user_params(
    pos_min_user: float,
    pos_max_user: float,
) -> MetricPalettePosUserParametersTagged:
    """
    Build parameters.
    
    Args:
        pos_min_user: the value for the least positive data.
        pos_max_user: the value for the most positive data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "pos_user",
        "pos_min_user": pos_min_user,
        "pos_max_user": pos_max_user,
    }
    return params


def metric_palette_pos_user_cargs(
    params: MetricPalettePosUserParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-pos-user")
    cargs.append(str(params.get("pos_min_user", None)))
    cargs.append(str(params.get("pos_max_user", None)))
    return cargs


def metric_palette_neg_user_params(
    neg_min_user: float,
    neg_max_user: float,
) -> MetricPaletteNegUserParametersTagged:
    """
    Build parameters.
    
    Args:
        neg_min_user: the value for the least negative data.
        neg_max_user: the value for the most negative data.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "neg_user",
        "neg_min_user": neg_min_user,
        "neg_max_user": neg_max_user,
    }
    return params


def metric_palette_neg_user_cargs(
    params: MetricPaletteNegUserParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-neg-user")
    cargs.append(str(params.get("neg_min_user", None)))
    cargs.append(str(params.get("neg_max_user", None)))
    return cargs


def metric_palette_thresholding_params(
    type_: str,
    test: str,
    min_: float,
    max_: float,
) -> MetricPaletteThresholdingParametersTagged:
    """
    Build parameters.
    
    Args:
        type_: thresholding setting.
        test: show values inside or outside thresholds.
        min_: lower threshold.
        max_: upper threshold.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "thresholding",
        "type": type_,
        "test": test,
        "min": min_,
        "max": max_,
    }
    return params


def metric_palette_thresholding_cargs(
    params: MetricPaletteThresholdingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-thresholding")
    cargs.append(params.get("type", None))
    cargs.append(params.get("test", None))
    cargs.append(str(params.get("min", None)))
    cargs.append(str(params.get("max", None)))
    return cargs


class MetricPaletteOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricPaletteParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def metric_palette_params(
    metric: str,
    mode: str,
    opt_column_column: str | None = None,
    pos_percent: MetricPalettePosPercentParameters | None = None,
    neg_percent: MetricPaletteNegPercentParameters | None = None,
    pos_user: MetricPalettePosUserParameters | None = None,
    neg_user: MetricPaletteNegUserParameters | None = None,
    opt_interpolate_interpolate: typing.Literal["true", "false"] | None = None,
    opt_disp_pos_display: typing.Literal["true", "false"] | None = None,
    opt_disp_neg_display: typing.Literal["true", "false"] | None = None,
    opt_disp_zero_display: typing.Literal["true", "false"] | None = None,
    opt_palette_name_name: str | None = None,
    thresholding: MetricPaletteThresholdingParameters | None = None,
    opt_inversion_type: str | None = None,
) -> MetricPaletteParametersTagged:
    """
    Build parameters.
    
    Args:
        metric: the metric to modify.
        mode: the mapping mode.
        opt_column_column: select a single column: the column number or name.
        pos_percent: percentage min/max for positive data coloring.
        neg_percent: percentage min/max for negative data coloring.
        pos_user: user min/max values for positive data coloring.
        neg_user: user min/max values for negative data coloring.
        opt_interpolate_interpolate: interpolate colors: boolean, whether to\
            interpolate.
        opt_disp_pos_display: display positive data: boolean, whether to\
            display.
        opt_disp_neg_display: display positive data: boolean, whether to\
            display.
        opt_disp_zero_display: display data closer to zero than the min cutoff:\
            boolean, whether to display.
        opt_palette_name_name: set the palette used: the name of the palette.
        thresholding: set the thresholding.
        opt_inversion_type: specify palette inversion: the type of inversion.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-palette",
        "metric": metric,
        "mode": mode,
    }
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if pos_percent is not None:
        params["pos_percent"] = pos_percent
    if neg_percent is not None:
        params["neg_percent"] = neg_percent
    if pos_user is not None:
        params["pos_user"] = pos_user
    if neg_user is not None:
        params["neg_user"] = neg_user
    if opt_interpolate_interpolate is not None:
        params["opt_interpolate_interpolate"] = opt_interpolate_interpolate
    if opt_disp_pos_display is not None:
        params["opt_disp_pos_display"] = opt_disp_pos_display
    if opt_disp_neg_display is not None:
        params["opt_disp_neg_display"] = opt_disp_neg_display
    if opt_disp_zero_display is not None:
        params["opt_disp_zero_display"] = opt_disp_zero_display
    if opt_palette_name_name is not None:
        params["opt_palette_name_name"] = opt_palette_name_name
    if thresholding is not None:
        params["thresholding"] = thresholding
    if opt_inversion_type is not None:
        params["opt_inversion_type"] = opt_inversion_type
    return params


def metric_palette_cargs(
    params: MetricPaletteParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-palette")
    cargs.append(params.get("metric", None))
    cargs.append(params.get("mode", None))
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("pos_percent", None) is not None:
        cargs.extend(metric_palette_pos_percent_cargs(params.get("pos_percent", None), execution))
    if params.get("neg_percent", None) is not None:
        cargs.extend(metric_palette_neg_percent_cargs(params.get("neg_percent", None), execution))
    if params.get("pos_user", None) is not None:
        cargs.extend(metric_palette_pos_user_cargs(params.get("pos_user", None), execution))
    if params.get("neg_user", None) is not None:
        cargs.extend(metric_palette_neg_user_cargs(params.get("neg_user", None), execution))
    if params.get("opt_interpolate_interpolate", None) is not None:
        cargs.extend([
            "-interpolate",
            params.get("opt_interpolate_interpolate", None)
        ])
    if params.get("opt_disp_pos_display", None) is not None:
        cargs.extend([
            "-disp-pos",
            params.get("opt_disp_pos_display", None)
        ])
    if params.get("opt_disp_neg_display", None) is not None:
        cargs.extend([
            "-disp-neg",
            params.get("opt_disp_neg_display", None)
        ])
    if params.get("opt_disp_zero_display", None) is not None:
        cargs.extend([
            "-disp-zero",
            params.get("opt_disp_zero_display", None)
        ])
    if params.get("opt_palette_name_name", None) is not None:
        cargs.extend([
            "-palette-name",
            params.get("opt_palette_name_name", None)
        ])
    if params.get("thresholding", None) is not None:
        cargs.extend(metric_palette_thresholding_cargs(params.get("thresholding", None), execution))
    if params.get("opt_inversion_type", None) is not None:
        cargs.extend([
            "-inversion",
            params.get("opt_inversion_type", None)
        ])
    return cargs


def metric_palette_outputs(
    params: MetricPaletteParameters,
    execution: Execution,
) -> MetricPaletteOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricPaletteOutputs(
        root=execution.output_file("."),
    )
    return ret


def metric_palette_execute(
    params: MetricPaletteParameters,
    runner: Runner | None = None,
) -> MetricPaletteOutputs:
    """
    metric-palette
    
    Set the palette of a metric file.
    
    The original metric file is overwritten with the modified version. By
    default, all columns of the metric file are adjusted to the new settings,
    use the -column option to change only one column. Mapping settings not
    specified in options will be taken from the first column. The <mode>
    argument must be one of the following:
    
    MODE_AUTO_SCALE
    MODE_AUTO_SCALE_ABSOLUTE_PERCENTAGE
    MODE_AUTO_SCALE_PERCENTAGE
    MODE_USER_SCALE
    
    The <name> argument to -palette-name must be one of the following:
    
    ROY-BIG-BL
    videen_style
    Gray_Interp_Positive
    Gray_Interp
    PSYCH-FIXED
    RBGYR20
    RBGYR20P
    RYGBR4_positive
    RGRBR_mirror90_pos
    Orange-Yellow
    POS_NEG_ZERO
    red-yellow
    blue-lightblue
    FSL
    power_surf
    black-red
    black-green
    black-blue
    black-red-positive
    black-green-positive
    black-blue-positive
    blue-black-green
    blue-black-red
    red-black-green
    fsl_red
    fsl_green
    fsl_blue
    fsl_yellow
    RedWhiteBlue
    cool-warm
    spectral
    RY-BC-BL
    magma
    JET256
    PSYCH
    PSYCH-NO-NONE
    ROY-BIG
    clear_brain
    fidl
    raich4_clrmid
    raich6_clrmid
    HSB8_clrmid
    POS_NEG
    Special-RGB-Volume
    
    The <type> argument to -thresholding must be one of the following:
    
    THRESHOLD_TYPE_OFF
    THRESHOLD_TYPE_NORMAL
    THRESHOLD_TYPE_FILE
    
    The <test> argument to -thresholding must be one of the following:
    
    THRESHOLD_TEST_SHOW_OUTSIDE
    THRESHOLD_TEST_SHOW_INSIDE
    
    The <type> argument to -inversion must be one of the following:
    
    OFF
    POSITIVE_WITH_NEGATIVE
    POSITIVE_NEGATIVE_SEPARATE
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricPaletteOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_PALETTE_METADATA)
    params = execution.params(params)
    cargs = metric_palette_cargs(params, execution)
    ret = metric_palette_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_palette(
    metric: str,
    mode: str,
    opt_column_column: str | None = None,
    pos_percent: MetricPalettePosPercentParameters | None = None,
    neg_percent: MetricPaletteNegPercentParameters | None = None,
    pos_user: MetricPalettePosUserParameters | None = None,
    neg_user: MetricPaletteNegUserParameters | None = None,
    opt_interpolate_interpolate: typing.Literal["true", "false"] | None = None,
    opt_disp_pos_display: typing.Literal["true", "false"] | None = None,
    opt_disp_neg_display: typing.Literal["true", "false"] | None = None,
    opt_disp_zero_display: typing.Literal["true", "false"] | None = None,
    opt_palette_name_name: str | None = None,
    thresholding: MetricPaletteThresholdingParameters | None = None,
    opt_inversion_type: str | None = None,
    runner: Runner | None = None,
) -> MetricPaletteOutputs:
    """
    metric-palette
    
    Set the palette of a metric file.
    
    The original metric file is overwritten with the modified version. By
    default, all columns of the metric file are adjusted to the new settings,
    use the -column option to change only one column. Mapping settings not
    specified in options will be taken from the first column. The <mode>
    argument must be one of the following:
    
    MODE_AUTO_SCALE
    MODE_AUTO_SCALE_ABSOLUTE_PERCENTAGE
    MODE_AUTO_SCALE_PERCENTAGE
    MODE_USER_SCALE
    
    The <name> argument to -palette-name must be one of the following:
    
    ROY-BIG-BL
    videen_style
    Gray_Interp_Positive
    Gray_Interp
    PSYCH-FIXED
    RBGYR20
    RBGYR20P
    RYGBR4_positive
    RGRBR_mirror90_pos
    Orange-Yellow
    POS_NEG_ZERO
    red-yellow
    blue-lightblue
    FSL
    power_surf
    black-red
    black-green
    black-blue
    black-red-positive
    black-green-positive
    black-blue-positive
    blue-black-green
    blue-black-red
    red-black-green
    fsl_red
    fsl_green
    fsl_blue
    fsl_yellow
    RedWhiteBlue
    cool-warm
    spectral
    RY-BC-BL
    magma
    JET256
    PSYCH
    PSYCH-NO-NONE
    ROY-BIG
    clear_brain
    fidl
    raich4_clrmid
    raich6_clrmid
    HSB8_clrmid
    POS_NEG
    Special-RGB-Volume
    
    The <type> argument to -thresholding must be one of the following:
    
    THRESHOLD_TYPE_OFF
    THRESHOLD_TYPE_NORMAL
    THRESHOLD_TYPE_FILE
    
    The <test> argument to -thresholding must be one of the following:
    
    THRESHOLD_TEST_SHOW_OUTSIDE
    THRESHOLD_TEST_SHOW_INSIDE
    
    The <type> argument to -inversion must be one of the following:
    
    OFF
    POSITIVE_WITH_NEGATIVE
    POSITIVE_NEGATIVE_SEPARATE
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric: the metric to modify.
        mode: the mapping mode.
        opt_column_column: select a single column: the column number or name.
        pos_percent: percentage min/max for positive data coloring.
        neg_percent: percentage min/max for negative data coloring.
        pos_user: user min/max values for positive data coloring.
        neg_user: user min/max values for negative data coloring.
        opt_interpolate_interpolate: interpolate colors: boolean, whether to\
            interpolate.
        opt_disp_pos_display: display positive data: boolean, whether to\
            display.
        opt_disp_neg_display: display positive data: boolean, whether to\
            display.
        opt_disp_zero_display: display data closer to zero than the min cutoff:\
            boolean, whether to display.
        opt_palette_name_name: set the palette used: the name of the palette.
        thresholding: set the thresholding.
        opt_inversion_type: specify palette inversion: the type of inversion.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricPaletteOutputs`).
    """
    params = metric_palette_params(
        metric=metric,
        mode=mode,
        opt_column_column=opt_column_column,
        pos_percent=pos_percent,
        neg_percent=neg_percent,
        pos_user=pos_user,
        neg_user=neg_user,
        opt_interpolate_interpolate=opt_interpolate_interpolate,
        opt_disp_pos_display=opt_disp_pos_display,
        opt_disp_neg_display=opt_disp_neg_display,
        opt_disp_zero_display=opt_disp_zero_display,
        opt_palette_name_name=opt_palette_name_name,
        thresholding=thresholding,
        opt_inversion_type=opt_inversion_type,
    )
    return metric_palette_execute(params, runner)


__all__ = [
    "METRIC_PALETTE_METADATA",
    "MetricPaletteOutputs",
    "metric_palette",
    "metric_palette_execute",
    "metric_palette_neg_percent_params",
    "metric_palette_neg_user_params",
    "metric_palette_params",
    "metric_palette_pos_percent_params",
    "metric_palette_pos_user_params",
    "metric_palette_thresholding_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_SMOOTHING_METADATA = Metadata(
    id="637bed2038ffd3c4196fb7689a2277fcbe539159.boutiques",
    name="surface-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceSmoothingParameters = typing.TypedDict('SurfaceSmoothingParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-smoothing"]],
    "surface_in": InputPathType,
    "smoothing_strength": float,
    "smoothing_iterations": int,
    "surface_out": str,
})
SurfaceSmoothingParametersTagged = typing.TypedDict('SurfaceSmoothingParametersTagged', {
    "@type": typing.Literal["workbench/surface-smoothing"],
    "surface_in": InputPathType,
    "smoothing_strength": float,
    "smoothing_iterations": int,
    "surface_out": str,
})


class SurfaceSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceSmoothingParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """output surface file"""


def surface_smoothing_params(
    surface_in: InputPathType,
    smoothing_strength: float,
    smoothing_iterations: int,
    surface_out: str,
) -> SurfaceSmoothingParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_in: the surface file to smooth.
        smoothing_strength: smoothing strength (ranges [0.0 - 1.0]).
        smoothing_iterations: smoothing iterations.
        surface_out: output surface file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-smoothing",
        "surface_in": surface_in,
        "smoothing_strength": smoothing_strength,
        "smoothing_iterations": smoothing_iterations,
        "surface_out": surface_out,
    }
    return params


def surface_smoothing_cargs(
    params: SurfaceSmoothingParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-smoothing")
    cargs.append(execution.input_file(params.get("surface_in", None)))
    cargs.append(str(params.get("smoothing_strength", None)))
    cargs.append(str(params.get("smoothing_iterations", None)))
    cargs.append(params.get("surface_out", None))
    return cargs


def surface_smoothing_outputs(
    params: SurfaceSmoothingParameters,
    execution: Execution,
) -> SurfaceSmoothingOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceSmoothingOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(params.get("surface_out", None)),
    )
    return ret


def surface_smoothing_execute(
    params: SurfaceSmoothingParameters,
    runner: Runner | None = None,
) -> SurfaceSmoothingOutputs:
    """
    surface-smoothing
    
    Surface smoothing.
    
    Smooths a surface by averaging vertex coordinates with those of the
    neighboring vertices.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_SMOOTHING_METADATA)
    params = execution.params(params)
    cargs = surface_smoothing_cargs(params, execution)
    ret = surface_smoothing_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_smoothing(
    surface_in: InputPathType,
    smoothing_strength: float,
    smoothing_iterations: int,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceSmoothingOutputs:
    """
    surface-smoothing
    
    Surface smoothing.
    
    Smooths a surface by averaging vertex coordinates with those of the
    neighboring vertices.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_in: the surface file to smooth.
        smoothing_strength: smoothing strength (ranges [0.0 - 1.0]).
        smoothing_iterations: smoothing iterations.
        surface_out: output surface file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSmoothingOutputs`).
    """
    params = surface_smoothing_params(
        surface_in=surface_in,
        smoothing_strength=smoothing_strength,
        smoothing_iterations=smoothing_iterations,
        surface_out=surface_out,
    )
    return surface_smoothing_execute(params, runner)


__all__ = [
    "SURFACE_SMOOTHING_METADATA",
    "SurfaceSmoothingOutputs",
    "surface_smoothing",
    "surface_smoothing_execute",
    "surface_smoothing_params",
]
